// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.UI.Text.h>

#include <winrt/Windows.Globalization.Fonts.h>

namespace py::proj::Windows::Globalization::Fonts
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::Globalization::Fonts::LanguageFont>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.fonts.LanguageFont";
        static constexpr const char* module_name = "winrt.windows.globalization.fonts";
        static constexpr const char* type_name = "LanguageFont";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::Fonts::LanguageFontGroup>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.fonts.LanguageFontGroup";
        static constexpr const char* module_name = "winrt.windows.globalization.fonts";
        static constexpr const char* type_name = "LanguageFontGroup";
    };
}

#if __has_include("py.Windows.UI.Text.h")
#include "py.Windows.UI.Text.h"
#endif

namespace py::impl::Windows::Globalization::Fonts
{
}

namespace py::wrapper::Windows::Globalization::Fonts
{
    using LanguageFont = py::winrt_wrapper<winrt::Windows::Globalization::Fonts::LanguageFont>;
    using LanguageFontGroup = py::winrt_wrapper<winrt::Windows::Globalization::Fonts::LanguageFontGroup>;
}

namespace py
{
}
