// WARNING: Please don't edit this file. It was generated by Python/WinRT v0.0.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "0.0.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.Appointments.h>
#include <winrt/Windows.ApplicationModel.Email.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Phone.Notification.Management.h>

namespace py::proj::Windows::Phone::Notification::Management
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::AccessoryNotificationType> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::CalendarChangedEvent> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneCallDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneCallState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneCallTransport> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneLineRegistrationState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneMediaType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PhoneNotificationType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PlaybackCapability> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PlaybackCommand> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::PlaybackStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::ReminderState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Notification::Management::VibrateState> = "i";


    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::AccessoryNotificationType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.AccessoryNotificationType";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "AccessoryNotificationType";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::CalendarChangedEvent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.CalendarChangedEvent";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "CalendarChangedEvent";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneCallAudioEndpoint>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneCallAudioEndpoint";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneCallAudioEndpoint";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneCallDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneCallDirection";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneCallDirection";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneCallState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneCallState";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneCallState";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneCallTransport>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneCallTransport";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneCallTransport";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneLineRegistrationState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneLineRegistrationState";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneLineRegistrationState";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneMediaType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneMediaType";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneMediaType";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneNotificationType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneNotificationType";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneNotificationType";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PlaybackCapability>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PlaybackCapability";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PlaybackCapability";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PlaybackCommand>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PlaybackCommand";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PlaybackCommand";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PlaybackStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PlaybackStatus";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PlaybackStatus";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::ReminderState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.ReminderState";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "ReminderState";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::VibrateState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.VibrateState";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "VibrateState";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::AccessoryManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.AccessoryManager";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "AccessoryManager";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::AlarmNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.AlarmNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "AlarmNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::AppNotificationInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.AppNotificationInfo";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "AppNotificationInfo";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::BinaryId>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.BinaryId";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "BinaryId";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::CalendarChangedNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.CalendarChangedNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "CalendarChangedNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::CortanaTileNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.CortanaTileNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "CortanaTileNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::EmailAccountInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.EmailAccountInfo";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "EmailAccountInfo";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::EmailFolderInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.EmailFolderInfo";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "EmailFolderInfo";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::EmailNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.EmailNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "EmailNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::EmailReadNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.EmailReadNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "EmailReadNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::MediaControlsTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.MediaControlsTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "MediaControlsTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::MediaMetadata>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.MediaMetadata";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "MediaMetadata";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneCallDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneCallDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneCallDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneLineDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneLineDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneLineDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::PhoneNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.PhoneNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "PhoneNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::ReminderNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.ReminderNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "ReminderNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::SpeedDialEntry>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.SpeedDialEntry";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "SpeedDialEntry";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::TextResponse>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.TextResponse";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "TextResponse";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::ToastNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.ToastNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "ToastNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::VolumeInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management.VolumeInfo";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "VolumeInfo";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.notification.management._IAccessoryNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.phone.notification.management";
        static constexpr const char* type_name = "_IAccessoryNotificationTriggerDetails";
    };
}

#if __has_include("py.Windows.ApplicationModel.Appointments.h")
#include "py.Windows.ApplicationModel.Appointments.h"
#endif

#if __has_include("py.Windows.ApplicationModel.Email.h")
#include "py.Windows.ApplicationModel.Email.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::Phone::Notification::Management
{
}

namespace py::wrapper::Windows::Phone::Notification::Management
{
    using AccessoryManager = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::AccessoryManager>;
    using AlarmNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::AlarmNotificationTriggerDetails>;
    using AppNotificationInfo = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::AppNotificationInfo>;
    using BinaryId = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::BinaryId>;
    using CalendarChangedNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::CalendarChangedNotificationTriggerDetails>;
    using CortanaTileNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::CortanaTileNotificationTriggerDetails>;
    using EmailAccountInfo = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::EmailAccountInfo>;
    using EmailFolderInfo = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::EmailFolderInfo>;
    using EmailNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::EmailNotificationTriggerDetails>;
    using EmailReadNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::EmailReadNotificationTriggerDetails>;
    using MediaControlsTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::MediaControlsTriggerDetails>;
    using MediaMetadata = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::MediaMetadata>;
    using PhoneCallDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::PhoneCallDetails>;
    using PhoneLineDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::PhoneLineDetails>;
    using PhoneNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::PhoneNotificationTriggerDetails>;
    using ReminderNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::ReminderNotificationTriggerDetails>;
    using SpeedDialEntry = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::SpeedDialEntry>;
    using TextResponse = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::TextResponse>;
    using ToastNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::ToastNotificationTriggerDetails>;
    using VolumeInfo = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::VolumeInfo>;
    using IAccessoryNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::Phone::Notification::Management::IAccessoryNotificationTriggerDetails>;
}

namespace py
{
}
