// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.System.Diagnostics.TraceReporting.h>

namespace py::proj::Windows::System::Diagnostics::TraceReporting
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticActionState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticEscalationType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticEventBufferLatencies> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTracePriority> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceSlotState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceSlotType> = "i";


    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticActionState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticActionState";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticActionState";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticEscalationType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticEscalationType";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticEscalationType";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticEventBufferLatencies>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticEventBufferLatencies";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticEventBufferLatencies";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTracePriority>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticTracePriority";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticTracePriority";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceSlotState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticTraceSlotState";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticTraceSlotState";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceSlotType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticTraceSlotType";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticTraceSlotType";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticActions>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticActions";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticActions";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticTraceInfo";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticTraceInfo";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceRuntimeInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.tracereporting.PlatformDiagnosticTraceRuntimeInfo";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.tracereporting";
        static constexpr const char* type_name = "PlatformDiagnosticTraceRuntimeInfo";
    };
}

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

namespace py::impl::Windows::System::Diagnostics::TraceReporting
{
}

namespace py::wrapper::Windows::System::Diagnostics::TraceReporting
{
    using PlatformDiagnosticActions = py::winrt_wrapper<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticActions>;
    using PlatformDiagnosticTraceInfo = py::winrt_wrapper<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceInfo>;
    using PlatformDiagnosticTraceRuntimeInfo = py::winrt_wrapper<winrt::Windows::System::Diagnostics::TraceReporting::PlatformDiagnosticTraceRuntimeInfo>;
}

namespace py
{
}
