// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.AI.Actions.h>
#include <winrt/Windows.Foundation.h>

#include <winrt/Windows.AI.Actions.Provider.h>

namespace py::proj::Windows::AI::Actions::Provider
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::AI::Actions::Provider::IActionFeedbackHandler>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ai.actions.provider._IActionFeedbackHandler";
        static constexpr const char* module_name = "winrt.windows.ai.actions.provider";
        static constexpr const char* type_name = "_IActionFeedbackHandler";
    };

    template<>
    struct py_type<winrt::Windows::AI::Actions::Provider::IActionProvider>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ai.actions.provider._IActionProvider";
        static constexpr const char* module_name = "winrt.windows.ai.actions.provider";
        static constexpr const char* type_name = "_IActionProvider";
    };
}

#if __has_include("py.Windows.AI.Actions.h")
#include "py.Windows.AI.Actions.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

namespace py::impl::Windows::AI::Actions::Provider
{
}

namespace py::wrapper::Windows::AI::Actions::Provider
{
    using IActionFeedbackHandler = py::winrt_wrapper<winrt::Windows::AI::Actions::Provider::IActionFeedbackHandler>;
    using IActionProvider = py::winrt_wrapper<winrt::Windows::AI::Actions::Provider::IActionProvider>;
}

namespace py
{
}
