// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");

#include <winrt/Windows.ApplicationModel.DataTransfer.DragDrop.h>

namespace py::proj::Windows::ApplicationModel::DataTransfer::DragDrop
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::DataTransfer::DragDrop::DragDropModifiers> = "I";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::DataTransfer::DragDrop::DragDropModifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.datatransfer.dragdrop.DragDropModifiers";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.datatransfer.dragdrop";
        static constexpr const char* type_name = "DragDropModifiers";
    };
}

namespace py::impl::Windows::ApplicationModel::DataTransfer::DragDrop
{
}

namespace py::wrapper::Windows::ApplicationModel::DataTransfer::DragDrop
{
}

namespace py
{
}
