// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");

#include <winrt/Windows.System.Diagnostics.Telemetry.h>

namespace py::proj::Windows::System::Diagnostics::Telemetry
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationStatus> = "i";


    template<>
    struct py_type<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.telemetry.PlatformTelemetryRegistrationStatus";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.telemetry";
        static constexpr const char* type_name = "PlatformTelemetryRegistrationStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryClient>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.telemetry.PlatformTelemetryClient";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.telemetry";
        static constexpr const char* type_name = "PlatformTelemetryClient";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.telemetry.PlatformTelemetryRegistrationResult";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.telemetry";
        static constexpr const char* type_name = "PlatformTelemetryRegistrationResult";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationSettings>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.telemetry.PlatformTelemetryRegistrationSettings";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.telemetry";
        static constexpr const char* type_name = "PlatformTelemetryRegistrationSettings";
    };
}

namespace py::impl::Windows::System::Diagnostics::Telemetry
{
}

namespace py::wrapper::Windows::System::Diagnostics::Telemetry
{
    using PlatformTelemetryClient = py::winrt_wrapper<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryClient>;
    using PlatformTelemetryRegistrationResult = py::winrt_wrapper<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationResult>;
    using PlatformTelemetryRegistrationSettings = py::winrt_wrapper<winrt::Windows::System::Diagnostics::Telemetry::PlatformTelemetryRegistrationSettings>;
}

namespace py
{
}
