// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.UI.Notifications.h>

#include <winrt/Windows.UI.Notifications.Management.h>

namespace py::proj::Windows::UI::Notifications::Management
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Notifications::Management::UserNotificationListenerAccessStatus> = "i";


    template<>
    struct py_type<winrt::Windows::UI::Notifications::Management::UserNotificationListenerAccessStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.notifications.management.UserNotificationListenerAccessStatus";
        static constexpr const char* module_name = "winrt.windows.ui.notifications.management";
        static constexpr const char* type_name = "UserNotificationListenerAccessStatus";
    };

    template<>
    struct py_type<winrt::Windows::UI::Notifications::Management::UserNotificationListener>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.notifications.management.UserNotificationListener";
        static constexpr const char* module_name = "winrt.windows.ui.notifications.management";
        static constexpr const char* type_name = "UserNotificationListener";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.UI.Notifications.h")
#include "py.Windows.UI.Notifications.h"
#endif

namespace py::impl::Windows::UI::Notifications::Management
{
}

namespace py::wrapper::Windows::UI::Notifications::Management
{
    using UserNotificationListener = py::winrt_wrapper<winrt::Windows::UI::Notifications::Management::UserNotificationListener>;
}

namespace py
{
}
