// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.Management.h>

namespace py::proj::Windows::Management
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Management::MdmAlertDataType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Management::MdmAlertMark> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Management::MdmSessionState> = "i";


    template<>
    struct py_type<winrt::Windows::Management::MdmAlertDataType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmAlertDataType";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmAlertDataType";
    };

    template<>
    struct py_type<winrt::Windows::Management::MdmAlertMark>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmAlertMark";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmAlertMark";
    };

    template<>
    struct py_type<winrt::Windows::Management::MdmSessionState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmSessionState";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmSessionState";
    };

    template<>
    struct py_type<winrt::Windows::Management::MdmAlert>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmAlert";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmAlert";
    };

    template<>
    struct py_type<winrt::Windows::Management::MdmSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmSession";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmSession";
    };

    template<>
    struct py_type<winrt::Windows::Management::MdmSessionManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.management.MdmSessionManager";
        static constexpr const char* module_name = "winrt.windows.management";
        static constexpr const char* type_name = "MdmSessionManager";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

namespace py::impl::Windows::Management
{
}

namespace py::wrapper::Windows::Management
{
    using MdmAlert = py::winrt_wrapper<winrt::Windows::Management::MdmAlert>;
    using MdmSession = py::winrt_wrapper<winrt::Windows::Management::MdmSession>;
    using MdmSessionManager = py::winrt_wrapper<winrt::Windows::Management::MdmSessionManager>;
}

namespace py
{
}
