// WARNING: Please don't edit this file. It was generated by Python/WinRT v0.0.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "0.0.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Phone.PersonalInformation.h>

namespace py::proj::Windows::Phone::PersonalInformation
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::PersonalInformation::ContactChangeType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::PersonalInformation::ContactQueryResultOrdering> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::PersonalInformation::ContactStoreApplicationAccessMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::PersonalInformation::ContactStoreSystemAccessMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::PersonalInformation::VCardFormat> = "i";


    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactChangeType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactChangeType";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactChangeType";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactQueryResultOrdering>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactQueryResultOrdering";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactQueryResultOrdering";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactStoreApplicationAccessMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactStoreApplicationAccessMode";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactStoreApplicationAccessMode";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactStoreSystemAccessMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactStoreSystemAccessMode";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactStoreSystemAccessMode";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::VCardFormat>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.VCardFormat";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "VCardFormat";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactAddress>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactAddress";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactAddress";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactChangeRecord>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactChangeRecord";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactChangeRecord";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactInformation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactInformation";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactInformation";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactQueryOptions>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactQueryOptions";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactQueryOptions";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactQueryResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactQueryResult";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactQueryResult";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::ContactStore>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.ContactStore";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "ContactStore";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::KnownContactProperties>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.KnownContactProperties";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "KnownContactProperties";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::StoredContact>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation.StoredContact";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "StoredContact";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::IContactInformation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation._IContactInformation";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "_IContactInformation";
    };

    template<>
    struct py_type<winrt::Windows::Phone::PersonalInformation::IContactInformation2>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.personalinformation._IContactInformation2";
        static constexpr const char* module_name = "winrt.windows.phone.personalinformation";
        static constexpr const char* type_name = "_IContactInformation2";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::Phone::PersonalInformation
{
}

namespace py::wrapper::Windows::Phone::PersonalInformation
{
    using ContactAddress = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactAddress>;
    using ContactChangeRecord = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactChangeRecord>;
    using ContactInformation = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactInformation>;
    using ContactQueryOptions = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactQueryOptions>;
    using ContactQueryResult = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactQueryResult>;
    using ContactStore = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::ContactStore>;
    using KnownContactProperties = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::KnownContactProperties>;
    using StoredContact = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::StoredContact>;
    using IContactInformation = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::IContactInformation>;
    using IContactInformation2 = py::winrt_wrapper<winrt::Windows::Phone::PersonalInformation::IContactInformation2>;
}

namespace py
{
}
