// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.AppService.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Networking.h>
#include <winrt/Windows.Security.Credentials.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.System.RemoteSystems.h>

namespace py::proj::Windows::System::RemoteSystems
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemAccessStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemAuthorizationKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemDiscoveryType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemPlatform> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionCreationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionDisconnectedReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionMessageChannelReliability> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantWatcherStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemSessionWatcherStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemStatusType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::RemoteSystems::RemoteSystemWatcherError> = "i";


    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemAccessStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemAccessStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemAccessStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemAuthorizationKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemAuthorizationKind";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemAuthorizationKind";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemDiscoveryType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemDiscoveryType";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemDiscoveryType";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemPlatform>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemPlatform";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemPlatform";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionCreationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionCreationStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionCreationStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionDisconnectedReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionDisconnectedReason";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionDisconnectedReason";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionJoinStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionJoinStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionMessageChannelReliability>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionMessageChannelReliability";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionMessageChannelReliability";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantWatcherStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionParticipantWatcherStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionParticipantWatcherStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionWatcherStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionWatcherStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionWatcherStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemStatus";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemStatus";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemStatusType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemStatusType";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemStatusType";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemWatcherError>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemWatcherError";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemWatcherError";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::KnownRemoteSystemCapabilities>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.KnownRemoteSystemCapabilities";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "KnownRemoteSystemCapabilities";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystem";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystem";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemAddedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemAddedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemAddedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemApp>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemApp";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemApp";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemAppRegistration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemAppRegistration";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemAppRegistration";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemAuthorizationKindFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemAuthorizationKindFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemAuthorizationKindFilter";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemConnectionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemConnectionInfo";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemConnectionInfo";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemConnectionRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemConnectionRequest";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemConnectionRequest";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemDiscoveryTypeFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemDiscoveryTypeFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemDiscoveryTypeFilter";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemEnumerationCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemEnumerationCompletedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemEnumerationCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemKindFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemKindFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemKindFilter";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemKinds>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemKinds";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemKinds";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemRemovedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemRemovedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemRemovedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSession";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSession";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionAddedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionAddedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionAddedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionController>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionController";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionController";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionCreationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionCreationResult";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionCreationResult";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionDisconnectedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionDisconnectedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionDisconnectedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionInfo";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionInfo";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionInvitation";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionInvitation";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitationListener>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionInvitationListener";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionInvitationListener";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitationReceivedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionInvitationReceivedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionInvitationReceivedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionJoinRequest";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionJoinRequest";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionJoinRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionJoinRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionJoinResult";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionJoinResult";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionMessageChannel>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionMessageChannel";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionMessageChannel";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionOptions>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionOptions";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionOptions";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipant>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionParticipant";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionParticipant";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantAddedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionParticipantAddedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionParticipantAddedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantRemovedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionParticipantRemovedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionParticipantRemovedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantWatcher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionParticipantWatcher";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionParticipantWatcher";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionRemovedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionRemovedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionRemovedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionUpdatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionUpdatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionUpdatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionValueSetReceivedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionValueSetReceivedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionValueSetReceivedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemSessionWatcher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemSessionWatcher";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemSessionWatcher";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemStatusTypeFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemStatusTypeFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemStatusTypeFilter";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemUpdatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemUpdatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemUpdatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemWatcher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemWatcher";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemWatcher";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemWatcherErrorOccurredEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemWatcherErrorOccurredEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemWatcherErrorOccurredEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::RemoteSystemWebAccountFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems.RemoteSystemWebAccountFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "RemoteSystemWebAccountFilter";
    };

    template<>
    struct py_type<winrt::Windows::System::RemoteSystems::IRemoteSystemFilter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.remotesystems._IRemoteSystemFilter";
        static constexpr const char* module_name = "winrt.windows.system.remotesystems";
        static constexpr const char* type_name = "_IRemoteSystemFilter";
    };
}

#if __has_include("py.Windows.ApplicationModel.AppService.h")
#include "py.Windows.ApplicationModel.AppService.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Networking.h")
#include "py.Windows.Networking.h"
#endif

#if __has_include("py.Windows.Security.Credentials.h")
#include "py.Windows.Security.Credentials.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

namespace py::impl::Windows::System::RemoteSystems
{
}

namespace py::wrapper::Windows::System::RemoteSystems
{
    using KnownRemoteSystemCapabilities = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::KnownRemoteSystemCapabilities>;
    using RemoteSystem = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystem>;
    using RemoteSystemAddedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemAddedEventArgs>;
    using RemoteSystemApp = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemApp>;
    using RemoteSystemAppRegistration = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemAppRegistration>;
    using RemoteSystemAuthorizationKindFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemAuthorizationKindFilter>;
    using RemoteSystemConnectionInfo = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemConnectionInfo>;
    using RemoteSystemConnectionRequest = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemConnectionRequest>;
    using RemoteSystemDiscoveryTypeFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemDiscoveryTypeFilter>;
    using RemoteSystemEnumerationCompletedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemEnumerationCompletedEventArgs>;
    using RemoteSystemKindFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemKindFilter>;
    using RemoteSystemKinds = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemKinds>;
    using RemoteSystemRemovedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemRemovedEventArgs>;
    using RemoteSystemSession = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSession>;
    using RemoteSystemSessionAddedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionAddedEventArgs>;
    using RemoteSystemSessionController = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionController>;
    using RemoteSystemSessionCreationResult = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionCreationResult>;
    using RemoteSystemSessionDisconnectedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionDisconnectedEventArgs>;
    using RemoteSystemSessionInfo = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInfo>;
    using RemoteSystemSessionInvitation = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitation>;
    using RemoteSystemSessionInvitationListener = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitationListener>;
    using RemoteSystemSessionInvitationReceivedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionInvitationReceivedEventArgs>;
    using RemoteSystemSessionJoinRequest = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinRequest>;
    using RemoteSystemSessionJoinRequestedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinRequestedEventArgs>;
    using RemoteSystemSessionJoinResult = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionJoinResult>;
    using RemoteSystemSessionMessageChannel = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionMessageChannel>;
    using RemoteSystemSessionOptions = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionOptions>;
    using RemoteSystemSessionParticipant = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipant>;
    using RemoteSystemSessionParticipantAddedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantAddedEventArgs>;
    using RemoteSystemSessionParticipantRemovedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantRemovedEventArgs>;
    using RemoteSystemSessionParticipantWatcher = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionParticipantWatcher>;
    using RemoteSystemSessionRemovedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionRemovedEventArgs>;
    using RemoteSystemSessionUpdatedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionUpdatedEventArgs>;
    using RemoteSystemSessionValueSetReceivedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionValueSetReceivedEventArgs>;
    using RemoteSystemSessionWatcher = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemSessionWatcher>;
    using RemoteSystemStatusTypeFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemStatusTypeFilter>;
    using RemoteSystemUpdatedEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemUpdatedEventArgs>;
    using RemoteSystemWatcher = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemWatcher>;
    using RemoteSystemWatcherErrorOccurredEventArgs = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemWatcherErrorOccurredEventArgs>;
    using RemoteSystemWebAccountFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::RemoteSystemWebAccountFilter>;
    using IRemoteSystemFilter = py::winrt_wrapper<winrt::Windows::System::RemoteSystems::IRemoteSystemFilter>;
}

namespace py
{
}
