// WARNING: Please don't edit this file. It was generated by Python/WinRT v0.0.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "0.0.0"), "Mismatched Py/WinRT headers.");

#include <winrt/Windows.Phone.Speech.Recognition.h>

namespace py::proj::Windows::Phone::Speech::Recognition
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Speech::Recognition::SpeechRecognitionUIStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Phone::Speech::Recognition::SpeechRecognitionUIStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.speech.recognition.SpeechRecognitionUIStatus";
        static constexpr const char* module_name = "winrt.windows.phone.speech.recognition";
        static constexpr const char* type_name = "SpeechRecognitionUIStatus";
    };
}

namespace py::impl::Windows::Phone::Speech::Recognition
{
}

namespace py::wrapper::Windows::Phone::Speech::Recognition
{
}

namespace py
{
}
