// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Devices.Sensors.h>
#include <winrt/Windows.Foundation.h>

#include <winrt/Windows.System.Preview.h>

namespace py::proj::Windows::System::Preview
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Preview::HingeState> = "i";


    template<>
    struct py_type<winrt::Windows::System::Preview::HingeState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.preview.HingeState";
        static constexpr const char* module_name = "winrt.windows.system.preview";
        static constexpr const char* type_name = "HingeState";
    };

    template<>
    struct py_type<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreview>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.preview.TwoPanelHingedDevicePosturePreview";
        static constexpr const char* module_name = "winrt.windows.system.preview";
        static constexpr const char* type_name = "TwoPanelHingedDevicePosturePreview";
    };

    template<>
    struct py_type<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreviewReading>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.preview.TwoPanelHingedDevicePosturePreviewReading";
        static constexpr const char* module_name = "winrt.windows.system.preview";
        static constexpr const char* type_name = "TwoPanelHingedDevicePosturePreviewReading";
    };

    template<>
    struct py_type<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreviewReadingChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.preview.TwoPanelHingedDevicePosturePreviewReadingChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.preview";
        static constexpr const char* type_name = "TwoPanelHingedDevicePosturePreviewReadingChangedEventArgs";
    };
}

#if __has_include("py.Windows.Devices.Sensors.h")
#include "py.Windows.Devices.Sensors.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

namespace py::impl::Windows::System::Preview
{
}

namespace py::wrapper::Windows::System::Preview
{
    using TwoPanelHingedDevicePosturePreview = py::winrt_wrapper<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreview>;
    using TwoPanelHingedDevicePosturePreviewReading = py::winrt_wrapper<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreviewReading>;
    using TwoPanelHingedDevicePosturePreviewReadingChangedEventArgs = py::winrt_wrapper<winrt::Windows::System::Preview::TwoPanelHingedDevicePosturePreviewReadingChangedEventArgs>;
}

namespace py
{
}
