// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Media.MediaProperties.h>
#include <winrt/Windows.Security.Credentials.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.ApplicationModel.Chat.h>

namespace py::proj::Windows::ApplicationModel::Chat
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatConversationThreadingKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatItemKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageOperatorKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageTransportKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatMessageValidationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatRestoreHistorySpan> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatStoreChangedEventKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatTransportErrorCodeCategory> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::ChatTransportInterpretedErrorCode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Chat::RcsServiceKind> = "i";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatConversationThreadingKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatConversationThreadingKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatConversationThreadingKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatItemKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatItemKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatItemKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChangeType";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChangeType";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageOperatorKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageOperatorKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageOperatorKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageStatus";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageStatus";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageTransportKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageTransportKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageTransportKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageValidationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageValidationStatus";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageValidationStatus";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatRestoreHistorySpan>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatRestoreHistorySpan";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatRestoreHistorySpan";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatStoreChangedEventKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatStoreChangedEventKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatStoreChangedEventKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatTransportErrorCodeCategory>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatTransportErrorCodeCategory";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatTransportErrorCodeCategory";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatTransportInterpretedErrorCode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatTransportInterpretedErrorCode";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatTransportInterpretedErrorCode";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsServiceKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsServiceKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsServiceKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatCapabilities>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatCapabilities";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatCapabilities";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatCapabilitiesManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatCapabilitiesManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatCapabilitiesManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatConversation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatConversation";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatConversation";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatConversationReader>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatConversationReader";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatConversationReader";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatConversationThreadingInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatConversationThreadingInfo";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatConversationThreadingInfo";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessage>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessage";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessage";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageAttachment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageAttachment";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageAttachment";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageBlocking>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageBlocking";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageBlocking";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChange>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChange";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChange";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeReader>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChangeReader";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChangeReader";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeTracker>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChangeTracker";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChangeTracker";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChangedDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChangedDeferral";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChangedDeferral";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageNotificationTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageNotificationTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageNotificationTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageReader>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageReader";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageReader";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageStore>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageStore";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageStore";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageStoreChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageStoreChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageStoreChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageTransport>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageTransport";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageTransport";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageTransportConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageTransportConfiguration";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageTransportConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatMessageValidationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatMessageValidationResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatMessageValidationResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatQueryOptions>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatQueryOptions";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatQueryOptions";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatRecipientDeliveryInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatRecipientDeliveryInfo";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatRecipientDeliveryInfo";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatSearchReader>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatSearchReader";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatSearchReader";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatSyncConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatSyncConfiguration";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatSyncConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::ChatSyncManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.ChatSyncManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "ChatSyncManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessage>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsEndUserMessage";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsEndUserMessage";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAction>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsEndUserMessageAction";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsEndUserMessageAction";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAvailableEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsEndUserMessageAvailableEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsEndUserMessageAvailableEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAvailableTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsEndUserMessageAvailableTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsEndUserMessageAvailableTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsEndUserMessageManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsEndUserMessageManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsServiceKindSupportedChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsServiceKindSupportedChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsServiceKindSupportedChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsTransport>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsTransport";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsTransport";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RcsTransportConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RcsTransportConfiguration";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RcsTransportConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::RemoteParticipantComposingChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat.RemoteParticipantComposingChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "RemoteParticipantComposingChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Chat::IChatItem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.chat._IChatItem";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.chat";
        static constexpr const char* type_name = "_IChatItem";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Media.MediaProperties.h")
#include "py.Windows.Media.MediaProperties.h"
#endif

#if __has_include("py.Windows.Security.Credentials.h")
#include "py.Windows.Security.Credentials.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::ApplicationModel::Chat
{
}

namespace py::wrapper::Windows::ApplicationModel::Chat
{
    using ChatCapabilities = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatCapabilities>;
    using ChatCapabilitiesManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatCapabilitiesManager>;
    using ChatConversation = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatConversation>;
    using ChatConversationReader = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatConversationReader>;
    using ChatConversationThreadingInfo = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatConversationThreadingInfo>;
    using ChatMessage = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessage>;
    using ChatMessageAttachment = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageAttachment>;
    using ChatMessageBlocking = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageBlocking>;
    using ChatMessageChange = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageChange>;
    using ChatMessageChangeReader = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeReader>;
    using ChatMessageChangeTracker = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageChangeTracker>;
    using ChatMessageChangedDeferral = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageChangedDeferral>;
    using ChatMessageChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageChangedEventArgs>;
    using ChatMessageManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageManager>;
    using ChatMessageNotificationTriggerDetails = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageNotificationTriggerDetails>;
    using ChatMessageReader = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageReader>;
    using ChatMessageStore = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageStore>;
    using ChatMessageStoreChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageStoreChangedEventArgs>;
    using ChatMessageTransport = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageTransport>;
    using ChatMessageTransportConfiguration = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageTransportConfiguration>;
    using ChatMessageValidationResult = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatMessageValidationResult>;
    using ChatQueryOptions = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatQueryOptions>;
    using ChatRecipientDeliveryInfo = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatRecipientDeliveryInfo>;
    using ChatSearchReader = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatSearchReader>;
    using ChatSyncConfiguration = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatSyncConfiguration>;
    using ChatSyncManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::ChatSyncManager>;
    using RcsEndUserMessage = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessage>;
    using RcsEndUserMessageAction = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAction>;
    using RcsEndUserMessageAvailableEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAvailableEventArgs>;
    using RcsEndUserMessageAvailableTriggerDetails = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageAvailableTriggerDetails>;
    using RcsEndUserMessageManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsEndUserMessageManager>;
    using RcsManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsManager>;
    using RcsServiceKindSupportedChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsServiceKindSupportedChangedEventArgs>;
    using RcsTransport = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsTransport>;
    using RcsTransportConfiguration = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RcsTransportConfiguration>;
    using RemoteParticipantComposingChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::RemoteParticipantComposingChangedEventArgs>;
    using IChatItem = py::winrt_wrapper<winrt::Windows::ApplicationModel::Chat::IChatItem>;
}

namespace py
{
}
