// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>

#include <winrt/Windows.ApplicationModel.Resources.Management.h>

namespace py::proj::Windows::ApplicationModel::Resources::Management
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceType> = "i";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.resources.management.IndexedResourceType";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.resources.management";
        static constexpr const char* type_name = "IndexedResourceType";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceCandidate>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.resources.management.IndexedResourceCandidate";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.resources.management";
        static constexpr const char* type_name = "IndexedResourceCandidate";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceQualifier>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.resources.management.IndexedResourceQualifier";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.resources.management";
        static constexpr const char* type_name = "IndexedResourceQualifier";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Resources::Management::ResourceIndexer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.resources.management.ResourceIndexer";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.resources.management";
        static constexpr const char* type_name = "ResourceIndexer";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

namespace py::impl::Windows::ApplicationModel::Resources::Management
{
}

namespace py::wrapper::Windows::ApplicationModel::Resources::Management
{
    using IndexedResourceCandidate = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceCandidate>;
    using IndexedResourceQualifier = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Management::IndexedResourceQualifier>;
    using ResourceIndexer = py::winrt_wrapper<winrt::Windows::ApplicationModel::Resources::Management::ResourceIndexer>;
}

namespace py
{
}
