// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.Contacts.h>
#include <winrt/Windows.ApplicationModel.DataTransfer.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.ApplicationModel.DataTransfer.ShareTarget.h>

namespace py::proj::Windows::ApplicationModel::DataTransfer::ShareTarget
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::ApplicationModel::DataTransfer::ShareTarget::QuickLink>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.datatransfer.sharetarget.QuickLink";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.datatransfer.sharetarget";
        static constexpr const char* type_name = "QuickLink";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::DataTransfer::ShareTarget::ShareOperation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.datatransfer.sharetarget.ShareOperation";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.datatransfer.sharetarget";
        static constexpr const char* type_name = "ShareOperation";
    };
}

#if __has_include("py.Windows.ApplicationModel.Contacts.h")
#include "py.Windows.ApplicationModel.Contacts.h"
#endif

#if __has_include("py.Windows.ApplicationModel.DataTransfer.h")
#include "py.Windows.ApplicationModel.DataTransfer.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::ApplicationModel::DataTransfer::ShareTarget
{
}

namespace py::wrapper::Windows::ApplicationModel::DataTransfer::ShareTarget
{
    using QuickLink = py::winrt_wrapper<winrt::Windows::ApplicationModel::DataTransfer::ShareTarget::QuickLink>;
    using ShareOperation = py::winrt_wrapper<winrt::Windows::ApplicationModel::DataTransfer::ShareTarget::ShareOperation>;
}

namespace py
{
}
