// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.250303.1

#pragma once
#ifndef WINRT_Windows_Security_Cryptography_1_H
#define WINRT_Windows_Security_Cryptography_1_H
#include "winrt/impl/Windows.Security.Cryptography.0.h"
WINRT_EXPORT namespace winrt::Windows::Security::Cryptography
{
    struct WINRT_IMPL_EMPTY_BASES ICryptographicBufferStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICryptographicBufferStatics>
    {
        ICryptographicBufferStatics(std::nullptr_t = nullptr) noexcept {}
        ICryptographicBufferStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
