// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Data.Xml.Dom.h>
#include <winrt/Windows.Devices.Sms.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Networking.h>
#include <winrt/Windows.Networking.Connectivity.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.Networking.NetworkOperators.h>

namespace py::proj::Windows::Networking::NetworkOperators
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::DataClasses> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimAuthenticationPreference> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimDiscoverResultKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimOperationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimProfileClass> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimProfileMetadataState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimProfileState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimWatcherStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationResponseCode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcherStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinFormat> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppOperationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::NetworkDeviceStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::NetworkOperatorDataUsageNotificationKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::NetworkOperatorEventMessageType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::NetworkRegistrationState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ProfileMediaType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringCapability> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringOperationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringOperationalState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringWiFiAuthenticationKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringWiFiBand> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::TetheringWiFiPerformancePriority> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::UiccAccessCondition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::UiccAppKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::UiccAppRecordKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::UssdResultCode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ESimProfileInstallProgress> = "T{i:total_size_in_bytes:i:installed_size_in_bytes:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Networking::NetworkOperators::ProfileUsage> = "T{I:usage_in_megabytes:T{q:universal_time:}:last_sync_time:}";


    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::DataClasses>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.DataClasses";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "DataClasses";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimAuthenticationPreference>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimAuthenticationPreference";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimAuthenticationPreference";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimDiscoverResultKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimDiscoverResultKind";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimDiscoverResultKind";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimOperationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimOperationStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimOperationStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfileClass>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfileClass";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfileClass";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfileMetadataState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfileMetadataState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfileMetadataState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfileState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfileState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfileState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimWatcherStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimWatcherStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimWatcherStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationResponseCode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.HotspotAuthenticationResponseCode";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "HotspotAuthenticationResponseCode";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcherStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAccountWatcherStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAccountWatcherStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceType";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceType";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandModemStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandModemStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinFormat>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinFormat";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinFormat";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinLockState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinLockState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinType";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinType";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandRadioState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandRadioState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandSlotState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandSlotState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppOperationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUiccAppOperationStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUiccAppOperationStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkDeviceStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkDeviceStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkDeviceStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorDataUsageNotificationKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorDataUsageNotificationKind";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorDataUsageNotificationKind";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorEventMessageType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorEventMessageType";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorEventMessageType";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkRegistrationState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkRegistrationState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkRegistrationState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ProfileMediaType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ProfileMediaType";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ProfileMediaType";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringCapability>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringCapability";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringCapability";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringOperationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringOperationStatus";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringOperationStatus";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringOperationalState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringOperationalState";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringOperationalState";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringWiFiAuthenticationKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringWiFiAuthenticationKind";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringWiFiAuthenticationKind";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringWiFiBand>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringWiFiBand";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringWiFiBand";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringWiFiPerformancePriority>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringWiFiPerformancePriority";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringWiFiPerformancePriority";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UiccAccessCondition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UiccAccessCondition";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UiccAccessCondition";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UiccAppKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UiccAppKind";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UiccAppKind";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UiccAppRecordKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UiccAppRecordKind";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UiccAppRecordKind";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UssdResultCode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UssdResultCode";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UssdResultCode";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESim>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESim";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESim";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimAddedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimAddedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimAddedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimDiscoverEvent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimDiscoverEvent";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimDiscoverEvent";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimDiscoverResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimDiscoverResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimDiscoverResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimDownloadProfileMetadataResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimDownloadProfileMetadataResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimDownloadProfileMetadataResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimManager";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimManager";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimOperationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimOperationResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimOperationResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimPolicy>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimPolicy";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimPolicy";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfile>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfile";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfile";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfileMetadata>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfileMetadata";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfileMetadata";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfilePolicy>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfilePolicy";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfilePolicy";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimRemovedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimRemovedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimRemovedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimServiceInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimServiceInfo";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimServiceInfo";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimUpdatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimUpdatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimUpdatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimWatcher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimWatcher";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimWatcher";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationContext>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.HotspotAuthenticationContext";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "HotspotAuthenticationContext";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.HotspotAuthenticationEventDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "HotspotAuthenticationEventDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.HotspotCredentialsAuthenticationResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "HotspotCredentialsAuthenticationResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::KnownCSimFilePaths>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.KnownCSimFilePaths";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "KnownCSimFilePaths";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::KnownRuimFilePaths>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.KnownRuimFilePaths";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "KnownRuimFilePaths";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::KnownSimFilePaths>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.KnownSimFilePaths";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "KnownSimFilePaths";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::KnownUSimFilePaths>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.KnownUSimFilePaths";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "KnownUSimFilePaths";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccount>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAccount";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAccount";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAccountEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAccountEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAccountUpdatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAccountUpdatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAccountWatcher";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAccountWatcher";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAntennaSar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandAntennaSar";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandAntennaSar";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellCdma>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellCdma";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellCdma";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellGsm>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellGsm";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellGsm";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellLte>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellLte";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellLte";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellNR>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellNR";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellNR";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellTdscdma>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellTdscdma";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellTdscdma";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellUmts>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellUmts";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellUmts";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellsInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCellsInfo";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCellsInfo";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCurrentSlotIndexChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandCurrentSlotIndexChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandCurrentSlotIndexChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceInformation";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceInformation";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceService>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceService";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceService";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceCommandEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceCommandEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceCommandResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceCommandResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceCommandSession";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceCommandSession";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceDataReceivedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceDataReceivedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceDataReceivedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceDataSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceDataSession";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceDataSession";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceInformation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceInformation";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceInformation";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandDeviceServiceTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandDeviceServiceTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModem>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandModem";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandModem";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandModemConfiguration";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandModemConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemIsolation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandModemIsolation";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandModemIsolation";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetwork>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandNetwork";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandNetwork";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetworkRegistrationStateChange>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandNetworkRegistrationStateChange";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandNetworkRegistrationStateChange";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetworkRegistrationStateChangeTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandNetworkRegistrationStateChangeTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandNetworkRegistrationStateChangeTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPco>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPco";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPco";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPcoDataChangeTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPcoDataChangeTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPcoDataChangeTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPin>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPin";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPin";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockStateChange>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinLockStateChange";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinLockStateChange";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockStateChangeTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinLockStateChangeTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinLockStateChangeTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinManager";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinManager";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinOperationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandPinOperationResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandPinOperationResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioStateChange>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandRadioStateChange";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandRadioStateChange";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioStateChangeTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandRadioStateChangeTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandRadioStateChangeTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSarManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandSarManager";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandSarManager";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandSlotInfo";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandSlotInfo";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotInfoChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandSlotInfoChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandSlotInfoChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandSlotManager";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandSlotManager";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandTransmissionStateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandTransmissionStateChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandTransmissionStateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUicc>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUicc";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUicc";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccApp>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUiccApp";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUiccApp";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppReadRecordResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUiccAppReadRecordResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUiccAppReadRecordResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppRecordDetailsResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUiccAppRecordDetailsResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUiccAppRecordDetailsResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppsResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.MobileBroadbandUiccAppsResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "MobileBroadbandUiccAppsResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorDataUsageTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorDataUsageTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorDataUsageTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorNotificationEventDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorNotificationEventDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorTetheringAccessPointConfiguration";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorTetheringAccessPointConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringClient>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorTetheringClient";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorTetheringClient";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorTetheringManager";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorTetheringManager";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorTetheringOperationResult";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorTetheringOperationResult";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringSessionAccessPointConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.NetworkOperatorTetheringSessionAccessPointConfiguration";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "NetworkOperatorTetheringSessionAccessPointConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ProvisionFromXmlDocumentResults";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ProvisionFromXmlDocumentResults";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ProvisionedProfile>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ProvisionedProfile";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ProvisionedProfile";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ProvisioningAgent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ProvisioningAgent";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ProvisioningAgent";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::TetheringEntitlementCheckTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.TetheringEntitlementCheckTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "TetheringEntitlementCheckTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UssdMessage>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UssdMessage";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UssdMessage";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UssdReply>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UssdReply";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UssdReply";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::UssdSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.UssdSession";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "UssdSession";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ESimProfileInstallProgress>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_networking_networkoperators.ESimProfileInstallProgress_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ESimProfileInstallProgress";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ESimProfileInstallProgress";
    };

    template<>
    struct py_type<winrt::Windows::Networking::NetworkOperators::ProfileUsage>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_networking_networkoperators.ProfileUsage_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.networking.networkoperators.ProfileUsage";
        static constexpr const char* module_name = "winrt.windows.networking.networkoperators";
        static constexpr const char* type_name = "ProfileUsage";
    };
}

#if __has_include("py.Windows.Data.Xml.Dom.h")
#include "py.Windows.Data.Xml.Dom.h"
#endif

#if __has_include("py.Windows.Devices.Sms.h")
#include "py.Windows.Devices.Sms.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Networking.h")
#include "py.Windows.Networking.h"
#endif

#if __has_include("py.Windows.Networking.Connectivity.h")
#include "py.Windows.Networking.Connectivity.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::Networking::NetworkOperators
{
}

namespace py::wrapper::Windows::Networking::NetworkOperators
{
    using ESim = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESim>;
    using ESimAddedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimAddedEventArgs>;
    using ESimDiscoverEvent = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimDiscoverEvent>;
    using ESimDiscoverResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimDiscoverResult>;
    using ESimDownloadProfileMetadataResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimDownloadProfileMetadataResult>;
    using ESimManager = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimManager>;
    using ESimOperationResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimOperationResult>;
    using ESimPolicy = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimPolicy>;
    using ESimProfile = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimProfile>;
    using ESimProfileMetadata = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimProfileMetadata>;
    using ESimProfilePolicy = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimProfilePolicy>;
    using ESimRemovedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimRemovedEventArgs>;
    using ESimServiceInfo = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimServiceInfo>;
    using ESimUpdatedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimUpdatedEventArgs>;
    using ESimWatcher = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ESimWatcher>;
    using HotspotAuthenticationContext = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationContext>;
    using HotspotAuthenticationEventDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::HotspotAuthenticationEventDetails>;
    using HotspotCredentialsAuthenticationResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::HotspotCredentialsAuthenticationResult>;
    using KnownCSimFilePaths = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::KnownCSimFilePaths>;
    using KnownRuimFilePaths = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::KnownRuimFilePaths>;
    using KnownSimFilePaths = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::KnownSimFilePaths>;
    using KnownUSimFilePaths = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::KnownUSimFilePaths>;
    using MobileBroadbandAccount = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccount>;
    using MobileBroadbandAccountEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountEventArgs>;
    using MobileBroadbandAccountUpdatedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountUpdatedEventArgs>;
    using MobileBroadbandAccountWatcher = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAccountWatcher>;
    using MobileBroadbandAntennaSar = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandAntennaSar>;
    using MobileBroadbandCellCdma = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellCdma>;
    using MobileBroadbandCellGsm = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellGsm>;
    using MobileBroadbandCellLte = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellLte>;
    using MobileBroadbandCellNR = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellNR>;
    using MobileBroadbandCellTdscdma = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellTdscdma>;
    using MobileBroadbandCellUmts = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellUmts>;
    using MobileBroadbandCellsInfo = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCellsInfo>;
    using MobileBroadbandCurrentSlotIndexChangedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandCurrentSlotIndexChangedEventArgs>;
    using MobileBroadbandDeviceInformation = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceInformation>;
    using MobileBroadbandDeviceService = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceService>;
    using MobileBroadbandDeviceServiceCommandEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandEventArgs>;
    using MobileBroadbandDeviceServiceCommandResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandResult>;
    using MobileBroadbandDeviceServiceCommandSession = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceCommandSession>;
    using MobileBroadbandDeviceServiceDataReceivedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceDataReceivedEventArgs>;
    using MobileBroadbandDeviceServiceDataSession = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceDataSession>;
    using MobileBroadbandDeviceServiceInformation = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceInformation>;
    using MobileBroadbandDeviceServiceTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandDeviceServiceTriggerDetails>;
    using MobileBroadbandModem = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModem>;
    using MobileBroadbandModemConfiguration = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemConfiguration>;
    using MobileBroadbandModemIsolation = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandModemIsolation>;
    using MobileBroadbandNetwork = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetwork>;
    using MobileBroadbandNetworkRegistrationStateChange = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetworkRegistrationStateChange>;
    using MobileBroadbandNetworkRegistrationStateChangeTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandNetworkRegistrationStateChangeTriggerDetails>;
    using MobileBroadbandPco = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPco>;
    using MobileBroadbandPcoDataChangeTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPcoDataChangeTriggerDetails>;
    using MobileBroadbandPin = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPin>;
    using MobileBroadbandPinLockStateChange = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockStateChange>;
    using MobileBroadbandPinLockStateChangeTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinLockStateChangeTriggerDetails>;
    using MobileBroadbandPinManager = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinManager>;
    using MobileBroadbandPinOperationResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandPinOperationResult>;
    using MobileBroadbandRadioStateChange = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioStateChange>;
    using MobileBroadbandRadioStateChangeTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandRadioStateChangeTriggerDetails>;
    using MobileBroadbandSarManager = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSarManager>;
    using MobileBroadbandSlotInfo = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotInfo>;
    using MobileBroadbandSlotInfoChangedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotInfoChangedEventArgs>;
    using MobileBroadbandSlotManager = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandSlotManager>;
    using MobileBroadbandTransmissionStateChangedEventArgs = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandTransmissionStateChangedEventArgs>;
    using MobileBroadbandUicc = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUicc>;
    using MobileBroadbandUiccApp = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccApp>;
    using MobileBroadbandUiccAppReadRecordResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppReadRecordResult>;
    using MobileBroadbandUiccAppRecordDetailsResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppRecordDetailsResult>;
    using MobileBroadbandUiccAppsResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::MobileBroadbandUiccAppsResult>;
    using NetworkOperatorDataUsageTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorDataUsageTriggerDetails>;
    using NetworkOperatorNotificationEventDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorNotificationEventDetails>;
    using NetworkOperatorTetheringAccessPointConfiguration = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringAccessPointConfiguration>;
    using NetworkOperatorTetheringClient = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringClient>;
    using NetworkOperatorTetheringManager = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringManager>;
    using NetworkOperatorTetheringOperationResult = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringOperationResult>;
    using NetworkOperatorTetheringSessionAccessPointConfiguration = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::NetworkOperatorTetheringSessionAccessPointConfiguration>;
    using ProvisionFromXmlDocumentResults = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ProvisionFromXmlDocumentResults>;
    using ProvisionedProfile = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ProvisionedProfile>;
    using ProvisioningAgent = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::ProvisioningAgent>;
    using TetheringEntitlementCheckTriggerDetails = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::TetheringEntitlementCheckTriggerDetails>;
    using UssdMessage = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::UssdMessage>;
    using UssdReply = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::UssdReply>;
    using UssdSession = py::winrt_wrapper<winrt::Windows::Networking::NetworkOperators::UssdSession>;
    using ESimProfileInstallProgress = py::winrt_struct_wrapper<winrt::Windows::Networking::NetworkOperators::ESimProfileInstallProgress>;
    using ProfileUsage = py::winrt_struct_wrapper<winrt::Windows::Networking::NetworkOperators::ProfileUsage>;
}

namespace py
{
}
