// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.Appointments.h>
#include <winrt/Windows.Foundation.h>

#include <winrt/Windows.ApplicationModel.Appointments.AppointmentsProvider.h>

namespace py::proj::Windows::ApplicationModel::Appointments::AppointmentsProvider
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::AddAppointmentOperation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider.AddAppointmentOperation";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider";
        static constexpr const char* type_name = "AddAppointmentOperation";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::AppointmentsProviderLaunchActionVerbs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider.AppointmentsProviderLaunchActionVerbs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider";
        static constexpr const char* type_name = "AppointmentsProviderLaunchActionVerbs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::RemoveAppointmentOperation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider.RemoveAppointmentOperation";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider";
        static constexpr const char* type_name = "RemoveAppointmentOperation";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::ReplaceAppointmentOperation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider.ReplaceAppointmentOperation";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.appointments.appointmentsprovider";
        static constexpr const char* type_name = "ReplaceAppointmentOperation";
    };
}

#if __has_include("py.Windows.ApplicationModel.Appointments.h")
#include "py.Windows.ApplicationModel.Appointments.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

namespace py::impl::Windows::ApplicationModel::Appointments::AppointmentsProvider
{
}

namespace py::wrapper::Windows::ApplicationModel::Appointments::AppointmentsProvider
{
    using AddAppointmentOperation = py::winrt_wrapper<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::AddAppointmentOperation>;
    using AppointmentsProviderLaunchActionVerbs = py::winrt_wrapper<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::AppointmentsProviderLaunchActionVerbs>;
    using RemoveAppointmentOperation = py::winrt_wrapper<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::RemoveAppointmentOperation>;
    using ReplaceAppointmentOperation = py::winrt_wrapper<winrt::Windows::ApplicationModel::Appointments::AppointmentsProvider::ReplaceAppointmentOperation>;
}

namespace py
{
}
