// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.Activation.h>
#include <winrt/Windows.Devices.Printers.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Graphics.Printing.PrintTicket.h>
#include <winrt/Windows.Storage.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.Graphics.Printing.Workflow.h>

namespace py::proj::Windows::Graphics::Printing::Workflow
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PdlConversionHostBasedProcessingOperations> = "I";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowAttributesMergePolicy> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobAbortReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobIssueKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConversionType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJobStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSessionStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUICompletionStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PdlConversionHostBasedProcessingOperations>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PdlConversionHostBasedProcessingOperations";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PdlConversionHostBasedProcessingOperations";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowAttributesMergePolicy>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowAttributesMergePolicy";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowAttributesMergePolicy";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobAbortReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobAbortReason";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobAbortReason";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobIssueKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobIssueKind";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobIssueKind";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConversionType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlConversionType";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlConversionType";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJobStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPrinterJobStatus";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPrinterJobStatus";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSessionStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSessionStatus";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSessionStatus";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSubmittedStatus";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSubmittedStatus";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUICompletionStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowUICompletionStatus";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowUICompletionStatus";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowBackgroundSession";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowBackgroundSession";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSetupRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowBackgroundSetupRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowBackgroundSetupRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowConfiguration";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowForegroundSession";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowForegroundSession";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSetupRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowForegroundSetupRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowForegroundSetupRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobActivatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobActivatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobActivatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobBackgroundSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobBackgroundSession";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobBackgroundSession";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobIssueDetectedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobIssueDetectedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobIssueDetectedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobNotificationEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobNotificationEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobNotificationEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobStartingEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobUISession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowJobUISession";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowJobUISession";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelSourceFileContent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowObjectModelSourceFileContent";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowObjectModelSourceFileContent";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelTargetPackage>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowObjectModelTargetPackage";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowObjectModelTargetPackage";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConverter>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlConverter";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlConverter";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlDataAvailableEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlDataAvailableEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlDataAvailableEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlModificationRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlModificationRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlModificationRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlSourceContent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlSourceContent";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlSourceContent";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlTargetStream>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPdlTargetStream";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPdlTargetStream";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJob>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowPrinterJob";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowPrinterJob";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSourceContent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSourceContent";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSourceContent";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSpoolStreamContent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSpoolStreamContent";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSpoolStreamContent";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowStreamTarget>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowStreamTarget";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowStreamTarget";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSubmittedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSubmittedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedOperation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowSubmittedOperation";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowSubmittedOperation";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTarget>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowTarget";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowTarget";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUIActivatedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowUIActivatedEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowUIActivatedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUILauncher>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowUILauncher";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowUILauncher";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterDataAvailableEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowVirtualPrinterDataAvailableEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowVirtualPrinterDataAvailableEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowVirtualPrinterSession";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowVirtualPrinterSession";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterTriggerDetails>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowVirtualPrinterTriggerDetails";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowVirtualPrinterTriggerDetails";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterUIEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowVirtualPrinterUIEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowVirtualPrinterUIEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowXpsDataAvailableEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.graphics.printing.workflow.PrintWorkflowXpsDataAvailableEventArgs";
        static constexpr const char* module_name = "winrt.windows.graphics.printing.workflow";
        static constexpr const char* type_name = "PrintWorkflowXpsDataAvailableEventArgs";
    };
}

#if __has_include("py.Windows.ApplicationModel.Activation.h")
#include "py.Windows.ApplicationModel.Activation.h"
#endif

#if __has_include("py.Windows.Devices.Printers.h")
#include "py.Windows.Devices.Printers.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Graphics.Printing.PrintTicket.h")
#include "py.Windows.Graphics.Printing.PrintTicket.h"
#endif

#if __has_include("py.Windows.Storage.h")
#include "py.Windows.Storage.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

namespace py::impl::Windows::Graphics::Printing::Workflow
{
}

namespace py::wrapper::Windows::Graphics::Printing::Workflow
{
    using PrintWorkflowBackgroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSession>;
    using PrintWorkflowBackgroundSetupRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowBackgroundSetupRequestedEventArgs>;
    using PrintWorkflowConfiguration = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowConfiguration>;
    using PrintWorkflowForegroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSession>;
    using PrintWorkflowForegroundSetupRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowForegroundSetupRequestedEventArgs>;
    using PrintWorkflowJobActivatedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobActivatedEventArgs>;
    using PrintWorkflowJobBackgroundSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobBackgroundSession>;
    using PrintWorkflowJobIssueDetectedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobIssueDetectedEventArgs>;
    using PrintWorkflowJobNotificationEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobNotificationEventArgs>;
    using PrintWorkflowJobStartingEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobStartingEventArgs>;
    using PrintWorkflowJobTriggerDetails = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobTriggerDetails>;
    using PrintWorkflowJobUISession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowJobUISession>;
    using PrintWorkflowObjectModelSourceFileContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelSourceFileContent>;
    using PrintWorkflowObjectModelTargetPackage = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowObjectModelTargetPackage>;
    using PrintWorkflowPdlConverter = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlConverter>;
    using PrintWorkflowPdlDataAvailableEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlDataAvailableEventArgs>;
    using PrintWorkflowPdlModificationRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlModificationRequestedEventArgs>;
    using PrintWorkflowPdlSourceContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlSourceContent>;
    using PrintWorkflowPdlTargetStream = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPdlTargetStream>;
    using PrintWorkflowPrinterJob = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowPrinterJob>;
    using PrintWorkflowSourceContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSourceContent>;
    using PrintWorkflowSpoolStreamContent = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSpoolStreamContent>;
    using PrintWorkflowStreamTarget = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowStreamTarget>;
    using PrintWorkflowSubmittedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedEventArgs>;
    using PrintWorkflowSubmittedOperation = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowSubmittedOperation>;
    using PrintWorkflowTarget = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTarget>;
    using PrintWorkflowTriggerDetails = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowTriggerDetails>;
    using PrintWorkflowUIActivatedEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUIActivatedEventArgs>;
    using PrintWorkflowUILauncher = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowUILauncher>;
    using PrintWorkflowVirtualPrinterDataAvailableEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterDataAvailableEventArgs>;
    using PrintWorkflowVirtualPrinterSession = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterSession>;
    using PrintWorkflowVirtualPrinterTriggerDetails = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterTriggerDetails>;
    using PrintWorkflowVirtualPrinterUIEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowVirtualPrinterUIEventArgs>;
    using PrintWorkflowXpsDataAvailableEventArgs = py::winrt_wrapper<winrt::Windows::Graphics::Printing::Workflow::PrintWorkflowXpsDataAvailableEventArgs>;
}

namespace py
{
}
