// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.UI.WindowManagement.h>

#include <winrt/Windows.UI.Core.Preview.h>

namespace py::proj::Windows::UI::Core::Preview
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::UI::Core::Preview::CoreAppWindowPreview>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.core.preview.CoreAppWindowPreview";
        static constexpr const char* module_name = "winrt.windows.ui.core.preview";
        static constexpr const char* type_name = "CoreAppWindowPreview";
    };

    template<>
    struct py_type<winrt::Windows::UI::Core::Preview::SystemNavigationCloseRequestedPreviewEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.core.preview.SystemNavigationCloseRequestedPreviewEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.core.preview";
        static constexpr const char* type_name = "SystemNavigationCloseRequestedPreviewEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Core::Preview::SystemNavigationManagerPreview>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.core.preview.SystemNavigationManagerPreview";
        static constexpr const char* module_name = "winrt.windows.ui.core.preview";
        static constexpr const char* type_name = "SystemNavigationManagerPreview";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.UI.WindowManagement.h")
#include "py.Windows.UI.WindowManagement.h"
#endif

namespace py::impl::Windows::UI::Core::Preview
{
}

namespace py::wrapper::Windows::UI::Core::Preview
{
    using CoreAppWindowPreview = py::winrt_wrapper<winrt::Windows::UI::Core::Preview::CoreAppWindowPreview>;
    using SystemNavigationCloseRequestedPreviewEventArgs = py::winrt_wrapper<winrt::Windows::UI::Core::Preview::SystemNavigationCloseRequestedPreviewEventArgs>;
    using SystemNavigationManagerPreview = py::winrt_wrapper<winrt::Windows::UI::Core::Preview::SystemNavigationManagerPreview>;
}

namespace py
{
}
