// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.AppService.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Graphics.DirectX.Direct3D11.h>
#include <winrt/Windows.Graphics.Imaging.h>
#include <winrt/Windows.Media.Capture.h>
#include <winrt/Windows.Media.Capture.Frames.h>
#include <winrt/Windows.Media.Devices.h>
#include <winrt/Windows.Media.Devices.Core.h>
#include <winrt/Windows.Media.FaceAnalysis.h>
#include <winrt/Windows.Media.MediaProperties.h>
#include <winrt/Windows.Media.Playback.h>
#include <winrt/Windows.Media.Protection.h>
#include <winrt/Windows.Media.Streaming.Adaptive.h>
#include <winrt/Windows.Networking.BackgroundTransfer.h>
#include <winrt/Windows.Storage.h>
#include <winrt/Windows.Storage.FileProperties.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.UI.h>

#include <winrt/Windows.Media.Core.h>

namespace py::proj::Windows::Media::Core
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::AudioDecoderDegradation> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::AudioDecoderDegradationReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::CodecCategory> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::CodecKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::FaceDetectionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaDecoderStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaSourceState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaSourceStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaStreamSourceClosedReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaStreamSourceErrorStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MediaTrackKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MseAppendMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MseEndOfStreamStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MseReadyState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::SceneAnalysisRecommendation> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedMetadataKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedMetadataTrackErrorCode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextBoutenPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextBoutenType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextDisplayAlignment> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextFlowDirection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextFontStyle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextLineAlignment> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextRubyAlign> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextRubyPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextRubyReserve> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextScrollMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextUnit> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextWeight> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextWrapping> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextWritingMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::VideoStabilizationEffectEnabledChangedReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::MseTimeRange> = "T{T{q:duration:}:start:T{q:duration:}:end:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextDouble> = "T{d:value:i:unit:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextPadding> = "T{d:before:d:after:d:start:d:end:i:unit:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextPoint> = "T{d:x:d:y:i:unit:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Media::Core::TimedTextSize> = "T{d:height:d:width:i:unit:}";


    template<>
    struct py_type<winrt::Windows::Media::Core::AudioDecoderDegradation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioDecoderDegradation";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioDecoderDegradation";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::AudioDecoderDegradationReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioDecoderDegradationReason";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioDecoderDegradationReason";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::CodecCategory>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.CodecCategory";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "CodecCategory";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::CodecKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.CodecKind";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "CodecKind";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::FaceDetectionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.FaceDetectionMode";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "FaceDetectionMode";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaDecoderStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaDecoderStatus";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaDecoderStatus";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceState";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceState";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceStatus";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceStatus";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceClosedReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceClosedReason";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceClosedReason";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceErrorStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceErrorStatus";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceErrorStatus";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaTrackKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaTrackKind";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaTrackKind";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseAppendMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseAppendMode";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseAppendMode";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseEndOfStreamStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseEndOfStreamStatus";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseEndOfStreamStatus";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseReadyState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseReadyState";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseReadyState";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SceneAnalysisRecommendation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SceneAnalysisRecommendation";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SceneAnalysisRecommendation";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataKind";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataKind";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataTrackErrorCode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataTrackErrorCode";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataTrackErrorCode";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextBoutenPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextBoutenPosition";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextBoutenPosition";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextBoutenType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextBoutenType";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextBoutenType";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextDisplayAlignment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextDisplayAlignment";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextDisplayAlignment";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextFlowDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextFlowDirection";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextFlowDirection";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextFontStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextFontStyle";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextFontStyle";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextLineAlignment>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextLineAlignment";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextLineAlignment";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextRubyAlign>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextRubyAlign";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextRubyAlign";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextRubyPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextRubyPosition";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextRubyPosition";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextRubyReserve>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextRubyReserve";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextRubyReserve";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextScrollMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextScrollMode";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextScrollMode";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextUnit>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextUnit";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextUnit";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextWeight>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextWeight";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextWeight";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextWrapping>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextWrapping";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextWrapping";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextWritingMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextWritingMode";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextWritingMode";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoStabilizationEffectEnabledChangedReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoStabilizationEffectEnabledChangedReason";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoStabilizationEffectEnabledChangedReason";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::AudioStreamDescriptor>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioStreamDescriptor";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioStreamDescriptor";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::AudioTrack>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioTrack";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioTrack";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::AudioTrackOpenFailedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioTrackOpenFailedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioTrackOpenFailedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::AudioTrackSupportInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.AudioTrackSupportInfo";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "AudioTrackSupportInfo";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::ChapterCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.ChapterCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "ChapterCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::CodecInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.CodecInfo";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "CodecInfo";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::CodecQuery>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.CodecQuery";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "CodecQuery";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::CodecSubtypes>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.CodecSubtypes";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "CodecSubtypes";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::DataCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.DataCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "DataCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::FaceDetectedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.FaceDetectedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "FaceDetectedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::FaceDetectionEffect>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.FaceDetectionEffect";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "FaceDetectionEffect";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::FaceDetectionEffectDefinition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.FaceDetectionEffectDefinition";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "FaceDetectionEffectDefinition";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::FaceDetectionEffectFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.FaceDetectionEffectFrame";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "FaceDetectionEffectFrame";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::HighDynamicRangeControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.HighDynamicRangeControl";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "HighDynamicRangeControl";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::HighDynamicRangeOutput>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.HighDynamicRangeOutput";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "HighDynamicRangeOutput";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::ImageCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.ImageCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "ImageCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::InitializeMediaStreamSourceRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.InitializeMediaStreamSourceRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "InitializeMediaStreamSourceRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::LowLightFusion>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.LowLightFusion";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "LowLightFusion";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::LowLightFusionResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.LowLightFusionResult";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "LowLightFusionResult";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaBinder>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaBinder";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaBinder";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaBindingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaBindingEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaBindingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaCueEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaCueEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaCueEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSource";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSource";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceAppServiceConnection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceAppServiceConnection";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceAppServiceConnection";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceError>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceError";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceError";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceOpenOperationCompletedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceOpenOperationCompletedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceOpenOperationCompletedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaSourceStateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaSourceStateChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaSourceStateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSample>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSample";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSample";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSamplePropertySet>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSamplePropertySet";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSamplePropertySet";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSampleProtectionProperties>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSampleProtectionProperties";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSampleProtectionProperties";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSource";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSource";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceClosedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceClosedRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceClosedRequest";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceClosedRequest";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSampleRenderedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSampleRenderedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSampleRenderedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSampleRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSampleRequest";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSampleRequest";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSampleRequestDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSampleRequestDeferral";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSampleRequestDeferral";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSampleRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSampleRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSampleRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceStartingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceStartingEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceStartingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceStartingRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceStartingRequest";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceStartingRequest";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceStartingRequestDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceStartingRequestDeferral";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceStartingRequestDeferral";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSwitchStreamsRequest";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSwitchStreamsRequest";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequestDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSwitchStreamsRequestDeferral";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSwitchStreamsRequestDeferral";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MediaStreamSourceSwitchStreamsRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MediaStreamSourceSwitchStreamsRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseSourceBuffer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseSourceBuffer";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseSourceBuffer";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseSourceBufferList>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseSourceBufferList";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseSourceBufferList";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseStreamSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseStreamSource";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseStreamSource";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SceneAnalysisEffect>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SceneAnalysisEffect";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SceneAnalysisEffect";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SceneAnalysisEffectDefinition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SceneAnalysisEffectDefinition";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SceneAnalysisEffectDefinition";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SceneAnalysisEffectFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SceneAnalysisEffectFrame";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SceneAnalysisEffectFrame";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SceneAnalyzedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SceneAnalyzedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SceneAnalyzedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::SpeechCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.SpeechCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "SpeechCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataStreamDescriptor>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataStreamDescriptor";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataStreamDescriptor";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataTrack>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataTrack";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataTrack";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataTrackError>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataTrackError";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataTrackError";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedMetadataTrackFailedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedMetadataTrackFailedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedMetadataTrackFailedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextBouten>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextBouten";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextBouten";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextLine>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextLine";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextLine";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextRegion>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextRegion";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextRegion";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextRuby>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextRuby";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextRuby";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextSource";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextSource";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextSourceResolveResultEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextSourceResolveResultEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextSourceResolveResultEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextStyle";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextStyle";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextSubformat>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextSubformat";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextSubformat";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoStabilizationEffect>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoStabilizationEffect";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoStabilizationEffect";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoStabilizationEffectDefinition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoStabilizationEffectDefinition";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoStabilizationEffectDefinition";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoStabilizationEffectEnabledChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoStabilizationEffectEnabledChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoStabilizationEffectEnabledChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoStreamDescriptor>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoStreamDescriptor";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoStreamDescriptor";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoTrack>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoTrack";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoTrack";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoTrackOpenFailedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoTrackOpenFailedEventArgs";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoTrackOpenFailedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::VideoTrackSupportInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.VideoTrackSupportInfo";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "VideoTrackSupportInfo";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::IMediaCue>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._IMediaCue";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_IMediaCue";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::IMediaSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._IMediaSource";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_IMediaSource";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::IMediaStreamDescriptor>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._IMediaStreamDescriptor";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_IMediaStreamDescriptor";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::IMediaStreamDescriptor2>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._IMediaStreamDescriptor2";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_IMediaStreamDescriptor2";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::IMediaTrack>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._IMediaTrack";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_IMediaTrack";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::ISingleSelectMediaTrackList>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._ISingleSelectMediaTrackList";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_ISingleSelectMediaTrackList";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::ITimedMetadataTrackProvider>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.media.core._ITimedMetadataTrackProvider";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "_ITimedMetadataTrackProvider";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::MseTimeRange>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_media_core.MseTimeRange_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.MseTimeRange";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "MseTimeRange";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextDouble>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_media_core.TimedTextDouble_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextDouble";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextDouble";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextPadding>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_media_core.TimedTextPadding_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextPadding";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextPadding";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextPoint>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_media_core.TimedTextPoint_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextPoint";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextPoint";
    };

    template<>
    struct py_type<winrt::Windows::Media::Core::TimedTextSize>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_media_core.TimedTextSize_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.media.core.TimedTextSize";
        static constexpr const char* module_name = "winrt.windows.media.core";
        static constexpr const char* type_name = "TimedTextSize";
    };
}

#if __has_include("py.Windows.ApplicationModel.AppService.h")
#include "py.Windows.ApplicationModel.AppService.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Graphics.DirectX.Direct3D11.h")
#include "py.Windows.Graphics.DirectX.Direct3D11.h"
#endif

#if __has_include("py.Windows.Graphics.Imaging.h")
#include "py.Windows.Graphics.Imaging.h"
#endif

#if __has_include("py.Windows.Media.Capture.h")
#include "py.Windows.Media.Capture.h"
#endif

#if __has_include("py.Windows.Media.Capture.Frames.h")
#include "py.Windows.Media.Capture.Frames.h"
#endif

#if __has_include("py.Windows.Media.Devices.h")
#include "py.Windows.Media.Devices.h"
#endif

#if __has_include("py.Windows.Media.Devices.Core.h")
#include "py.Windows.Media.Devices.Core.h"
#endif

#if __has_include("py.Windows.Media.FaceAnalysis.h")
#include "py.Windows.Media.FaceAnalysis.h"
#endif

#if __has_include("py.Windows.Media.MediaProperties.h")
#include "py.Windows.Media.MediaProperties.h"
#endif

#if __has_include("py.Windows.Media.Playback.h")
#include "py.Windows.Media.Playback.h"
#endif

#if __has_include("py.Windows.Media.Protection.h")
#include "py.Windows.Media.Protection.h"
#endif

#if __has_include("py.Windows.Media.Streaming.Adaptive.h")
#include "py.Windows.Media.Streaming.Adaptive.h"
#endif

#if __has_include("py.Windows.Networking.BackgroundTransfer.h")
#include "py.Windows.Networking.BackgroundTransfer.h"
#endif

#if __has_include("py.Windows.Storage.h")
#include "py.Windows.Storage.h"
#endif

#if __has_include("py.Windows.Storage.FileProperties.h")
#include "py.Windows.Storage.FileProperties.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

namespace py::impl::Windows::Media::Core
{
}

namespace py::wrapper::Windows::Media::Core
{
    using AudioStreamDescriptor = py::winrt_wrapper<winrt::Windows::Media::Core::AudioStreamDescriptor>;
    using AudioTrack = py::winrt_wrapper<winrt::Windows::Media::Core::AudioTrack>;
    using AudioTrackOpenFailedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::AudioTrackOpenFailedEventArgs>;
    using AudioTrackSupportInfo = py::winrt_wrapper<winrt::Windows::Media::Core::AudioTrackSupportInfo>;
    using ChapterCue = py::winrt_wrapper<winrt::Windows::Media::Core::ChapterCue>;
    using CodecInfo = py::winrt_wrapper<winrt::Windows::Media::Core::CodecInfo>;
    using CodecQuery = py::winrt_wrapper<winrt::Windows::Media::Core::CodecQuery>;
    using CodecSubtypes = py::winrt_wrapper<winrt::Windows::Media::Core::CodecSubtypes>;
    using DataCue = py::winrt_wrapper<winrt::Windows::Media::Core::DataCue>;
    using FaceDetectedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::FaceDetectedEventArgs>;
    using FaceDetectionEffect = py::winrt_wrapper<winrt::Windows::Media::Core::FaceDetectionEffect>;
    using FaceDetectionEffectDefinition = py::winrt_wrapper<winrt::Windows::Media::Core::FaceDetectionEffectDefinition>;
    using FaceDetectionEffectFrame = py::winrt_wrapper<winrt::Windows::Media::Core::FaceDetectionEffectFrame>;
    using HighDynamicRangeControl = py::winrt_wrapper<winrt::Windows::Media::Core::HighDynamicRangeControl>;
    using HighDynamicRangeOutput = py::winrt_wrapper<winrt::Windows::Media::Core::HighDynamicRangeOutput>;
    using ImageCue = py::winrt_wrapper<winrt::Windows::Media::Core::ImageCue>;
    using InitializeMediaStreamSourceRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::InitializeMediaStreamSourceRequestedEventArgs>;
    using LowLightFusion = py::winrt_wrapper<winrt::Windows::Media::Core::LowLightFusion>;
    using LowLightFusionResult = py::winrt_wrapper<winrt::Windows::Media::Core::LowLightFusionResult>;
    using MediaBinder = py::winrt_wrapper<winrt::Windows::Media::Core::MediaBinder>;
    using MediaBindingEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaBindingEventArgs>;
    using MediaCueEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaCueEventArgs>;
    using MediaSource = py::winrt_wrapper<winrt::Windows::Media::Core::MediaSource>;
    using MediaSourceAppServiceConnection = py::winrt_wrapper<winrt::Windows::Media::Core::MediaSourceAppServiceConnection>;
    using MediaSourceError = py::winrt_wrapper<winrt::Windows::Media::Core::MediaSourceError>;
    using MediaSourceOpenOperationCompletedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaSourceOpenOperationCompletedEventArgs>;
    using MediaSourceStateChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaSourceStateChangedEventArgs>;
    using MediaStreamSample = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSample>;
    using MediaStreamSamplePropertySet = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSamplePropertySet>;
    using MediaStreamSampleProtectionProperties = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSampleProtectionProperties>;
    using MediaStreamSource = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSource>;
    using MediaStreamSourceClosedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceClosedEventArgs>;
    using MediaStreamSourceClosedRequest = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceClosedRequest>;
    using MediaStreamSourceSampleRenderedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSampleRenderedEventArgs>;
    using MediaStreamSourceSampleRequest = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSampleRequest>;
    using MediaStreamSourceSampleRequestDeferral = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSampleRequestDeferral>;
    using MediaStreamSourceSampleRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSampleRequestedEventArgs>;
    using MediaStreamSourceStartingEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceStartingEventArgs>;
    using MediaStreamSourceStartingRequest = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceStartingRequest>;
    using MediaStreamSourceStartingRequestDeferral = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceStartingRequestDeferral>;
    using MediaStreamSourceSwitchStreamsRequest = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequest>;
    using MediaStreamSourceSwitchStreamsRequestDeferral = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequestDeferral>;
    using MediaStreamSourceSwitchStreamsRequestedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::MediaStreamSourceSwitchStreamsRequestedEventArgs>;
    using MseSourceBuffer = py::winrt_wrapper<winrt::Windows::Media::Core::MseSourceBuffer>;
    using MseSourceBufferList = py::winrt_wrapper<winrt::Windows::Media::Core::MseSourceBufferList>;
    using MseStreamSource = py::winrt_wrapper<winrt::Windows::Media::Core::MseStreamSource>;
    using SceneAnalysisEffect = py::winrt_wrapper<winrt::Windows::Media::Core::SceneAnalysisEffect>;
    using SceneAnalysisEffectDefinition = py::winrt_wrapper<winrt::Windows::Media::Core::SceneAnalysisEffectDefinition>;
    using SceneAnalysisEffectFrame = py::winrt_wrapper<winrt::Windows::Media::Core::SceneAnalysisEffectFrame>;
    using SceneAnalyzedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::SceneAnalyzedEventArgs>;
    using SpeechCue = py::winrt_wrapper<winrt::Windows::Media::Core::SpeechCue>;
    using TimedMetadataStreamDescriptor = py::winrt_wrapper<winrt::Windows::Media::Core::TimedMetadataStreamDescriptor>;
    using TimedMetadataTrack = py::winrt_wrapper<winrt::Windows::Media::Core::TimedMetadataTrack>;
    using TimedMetadataTrackError = py::winrt_wrapper<winrt::Windows::Media::Core::TimedMetadataTrackError>;
    using TimedMetadataTrackFailedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::TimedMetadataTrackFailedEventArgs>;
    using TimedTextBouten = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextBouten>;
    using TimedTextCue = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextCue>;
    using TimedTextLine = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextLine>;
    using TimedTextRegion = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextRegion>;
    using TimedTextRuby = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextRuby>;
    using TimedTextSource = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextSource>;
    using TimedTextSourceResolveResultEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextSourceResolveResultEventArgs>;
    using TimedTextStyle = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextStyle>;
    using TimedTextSubformat = py::winrt_wrapper<winrt::Windows::Media::Core::TimedTextSubformat>;
    using VideoStabilizationEffect = py::winrt_wrapper<winrt::Windows::Media::Core::VideoStabilizationEffect>;
    using VideoStabilizationEffectDefinition = py::winrt_wrapper<winrt::Windows::Media::Core::VideoStabilizationEffectDefinition>;
    using VideoStabilizationEffectEnabledChangedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::VideoStabilizationEffectEnabledChangedEventArgs>;
    using VideoStreamDescriptor = py::winrt_wrapper<winrt::Windows::Media::Core::VideoStreamDescriptor>;
    using VideoTrack = py::winrt_wrapper<winrt::Windows::Media::Core::VideoTrack>;
    using VideoTrackOpenFailedEventArgs = py::winrt_wrapper<winrt::Windows::Media::Core::VideoTrackOpenFailedEventArgs>;
    using VideoTrackSupportInfo = py::winrt_wrapper<winrt::Windows::Media::Core::VideoTrackSupportInfo>;
    using IMediaCue = py::winrt_wrapper<winrt::Windows::Media::Core::IMediaCue>;
    using IMediaSource = py::winrt_wrapper<winrt::Windows::Media::Core::IMediaSource>;
    using IMediaStreamDescriptor = py::winrt_wrapper<winrt::Windows::Media::Core::IMediaStreamDescriptor>;
    using IMediaStreamDescriptor2 = py::winrt_wrapper<winrt::Windows::Media::Core::IMediaStreamDescriptor2>;
    using IMediaTrack = py::winrt_wrapper<winrt::Windows::Media::Core::IMediaTrack>;
    using ISingleSelectMediaTrackList = py::winrt_wrapper<winrt::Windows::Media::Core::ISingleSelectMediaTrackList>;
    using ITimedMetadataTrackProvider = py::winrt_wrapper<winrt::Windows::Media::Core::ITimedMetadataTrackProvider>;
    using MseTimeRange = py::winrt_struct_wrapper<winrt::Windows::Media::Core::MseTimeRange>;
    using TimedTextDouble = py::winrt_struct_wrapper<winrt::Windows::Media::Core::TimedTextDouble>;
    using TimedTextPadding = py::winrt_struct_wrapper<winrt::Windows::Media::Core::TimedTextPadding>;
    using TimedTextPoint = py::winrt_struct_wrapper<winrt::Windows::Media::Core::TimedTextPoint>;
    using TimedTextSize = py::winrt_struct_wrapper<winrt::Windows::Media::Core::TimedTextSize>;
}

namespace py
{
}
