// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Media.Audio.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.ApplicationModel.ConversationalAgent.h>

namespace py::proj::Windows::ApplicationModel::ConversationalAgent
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationCreationStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationRemovalResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationSetModelDataResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationStateChangeResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionTrainingDataFormat> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectorKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectorPowerState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentActivationKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentActivationResult> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSessionUpdateResponse> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSystemStateChangeType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentVoiceActivationPrerequisiteKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityChangeKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationTrainingStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::ConversationalAgent::SignalDetectorResourceKind> = "i";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationCreationStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfigurationCreationStatus";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfigurationCreationStatus";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationRemovalResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfigurationRemovalResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfigurationRemovalResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationSetModelDataResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfigurationSetModelDataResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfigurationSetModelDataResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationStateChangeResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfigurationStateChangeResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfigurationStateChangeResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionTrainingDataFormat>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionTrainingDataFormat";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionTrainingDataFormat";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectorKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectorKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectorKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectorPowerState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectorPowerState";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectorPowerState";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentActivationKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentActivationKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentActivationKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentActivationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentActivationResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentActivationResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSessionUpdateResponse>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSessionUpdateResponse";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSessionUpdateResponse";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentState";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentState";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSystemStateChangeType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSystemStateChangeType";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSystemStateChangeType";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentVoiceActivationPrerequisiteKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentVoiceActivationPrerequisiteKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentVoiceActivationPrerequisiteKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityChangeKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.DetectionConfigurationAvailabilityChangeKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "DetectionConfigurationAvailabilityChangeKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationTrainingStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.DetectionConfigurationTrainingStatus";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "DetectionConfigurationTrainingStatus";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::SignalDetectorResourceKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.SignalDetectorResourceKind";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "SignalDetectorResourceKind";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfiguration";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationCreationResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetectionConfigurationCreationResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetectionConfigurationCreationResult";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetector>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ActivationSignalDetector";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ActivationSignalDetector";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentDetectorManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentDetectorManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentDetectorManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSession>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSession";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSession";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSessionInterruptedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSessionInterruptedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSessionInterruptedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSignal>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSignal";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSignal";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSignalDetectedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSignalDetectedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSignalDetectedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSystemStateChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.ConversationalAgentSystemStateChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "ConversationalAgentSystemStateChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.DetectionConfigurationAvailabilityChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "DetectionConfigurationAvailabilityChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.conversationalagent.DetectionConfigurationAvailabilityInfo";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.conversationalagent";
        static constexpr const char* type_name = "DetectionConfigurationAvailabilityInfo";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Media.Audio.h")
#include "py.Windows.Media.Audio.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::ApplicationModel::ConversationalAgent
{
}

namespace py::wrapper::Windows::ApplicationModel::ConversationalAgent
{
    using ActivationSignalDetectionConfiguration = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfiguration>;
    using ActivationSignalDetectionConfigurationCreationResult = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetectionConfigurationCreationResult>;
    using ActivationSignalDetector = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ActivationSignalDetector>;
    using ConversationalAgentDetectorManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentDetectorManager>;
    using ConversationalAgentSession = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSession>;
    using ConversationalAgentSessionInterruptedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSessionInterruptedEventArgs>;
    using ConversationalAgentSignal = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSignal>;
    using ConversationalAgentSignalDetectedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSignalDetectedEventArgs>;
    using ConversationalAgentSystemStateChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::ConversationalAgentSystemStateChangedEventArgs>;
    using DetectionConfigurationAvailabilityChangedEventArgs = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityChangedEventArgs>;
    using DetectionConfigurationAvailabilityInfo = py::winrt_wrapper<winrt::Windows::ApplicationModel::ConversationalAgent::DetectionConfigurationAvailabilityInfo>;
}

namespace py
{
}
