// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Automation.Peers.h>

#include <winrt/Windows.UI.Xaml.Automation.h>

namespace py::proj::Windows::UI::Xaml::Automation
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AnnotationType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationActiveEnd> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationAnimationStyle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationBulletStyle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationCaretBidiMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationCaretPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationFlowDirections> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationOutlineStyles> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationStyleId> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationTextDecorationLineStyle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::AutomationTextEditChangeType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::DockPosition> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::ExpandCollapseState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::RowOrColumnMajor> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::ScrollAmount> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::SupportedTextSelection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::SynchronizedInputType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::ToggleState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::WindowInteractionState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::WindowVisualState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Automation::ZoomUnit> = "i";


    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AnnotationType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AnnotationType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AnnotationType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationActiveEnd>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationActiveEnd";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationActiveEnd";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationAnimationStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationAnimationStyle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationAnimationStyle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationBulletStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationBulletStyle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationBulletStyle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationCaretBidiMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationCaretBidiMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationCaretBidiMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationCaretPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationCaretPosition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationCaretPosition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationFlowDirections>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationFlowDirections";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationFlowDirections";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationOutlineStyles>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationOutlineStyles";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationOutlineStyles";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationStyleId>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationStyleId";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationStyleId";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationTextDecorationLineStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationTextDecorationLineStyle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationTextDecorationLineStyle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationTextEditChangeType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationTextEditChangeType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationTextEditChangeType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::DockPosition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.DockPosition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "DockPosition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ExpandCollapseState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ExpandCollapseState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ExpandCollapseState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::RowOrColumnMajor>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.RowOrColumnMajor";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "RowOrColumnMajor";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ScrollAmount>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ScrollAmount";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ScrollAmount";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::SupportedTextSelection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.SupportedTextSelection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "SupportedTextSelection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::SynchronizedInputType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.SynchronizedInputType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "SynchronizedInputType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ToggleState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ToggleState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ToggleState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::WindowInteractionState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.WindowInteractionState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "WindowInteractionState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::WindowVisualState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.WindowVisualState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "WindowVisualState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ZoomUnit>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ZoomUnit";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ZoomUnit";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AnnotationPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AnnotationPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AnnotationPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationAnnotation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationAnnotation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationAnnotation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationElementIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationElementIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationElementIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationProperties>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationProperties";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationProperties";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::AutomationProperty>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.AutomationProperty";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "AutomationProperty";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::DockPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.DockPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "DockPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::DragPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.DragPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "DragPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::DropTargetPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.DropTargetPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "DropTargetPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ExpandCollapsePatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ExpandCollapsePatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ExpandCollapsePatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::GridItemPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.GridItemPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "GridItemPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::GridPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.GridPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "GridPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::MultipleViewPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.MultipleViewPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "MultipleViewPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::RangeValuePatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.RangeValuePatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "RangeValuePatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ScrollPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ScrollPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ScrollPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::SelectionItemPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.SelectionItemPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "SelectionItemPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::SelectionPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.SelectionPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "SelectionPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::SpreadsheetItemPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.SpreadsheetItemPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "SpreadsheetItemPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::StylesPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.StylesPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "StylesPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::TableItemPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.TableItemPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "TableItemPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::TablePatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.TablePatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "TablePatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::TogglePatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.TogglePatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "TogglePatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::TransformPattern2Identifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.TransformPattern2Identifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "TransformPattern2Identifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::TransformPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.TransformPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "TransformPatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::ValuePatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.ValuePatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "ValuePatternIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Automation::WindowPatternIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.automation.WindowPatternIdentifiers";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.automation";
        static constexpr const char* type_name = "WindowPatternIdentifiers";
    };
}

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Automation.Peers.h")
#include "py.Windows.UI.Xaml.Automation.Peers.h"
#endif

namespace py::impl::Windows::UI::Xaml::Automation
{
}

namespace py::wrapper::Windows::UI::Xaml::Automation
{
    using AnnotationPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::AnnotationPatternIdentifiers>;
    using AutomationAnnotation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::AutomationAnnotation>;
    using AutomationElementIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::AutomationElementIdentifiers>;
    using AutomationProperties = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::AutomationProperties>;
    using AutomationProperty = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::AutomationProperty>;
    using DockPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::DockPatternIdentifiers>;
    using DragPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::DragPatternIdentifiers>;
    using DropTargetPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::DropTargetPatternIdentifiers>;
    using ExpandCollapsePatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::ExpandCollapsePatternIdentifiers>;
    using GridItemPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::GridItemPatternIdentifiers>;
    using GridPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::GridPatternIdentifiers>;
    using MultipleViewPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::MultipleViewPatternIdentifiers>;
    using RangeValuePatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::RangeValuePatternIdentifiers>;
    using ScrollPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::ScrollPatternIdentifiers>;
    using SelectionItemPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::SelectionItemPatternIdentifiers>;
    using SelectionPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::SelectionPatternIdentifiers>;
    using SpreadsheetItemPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::SpreadsheetItemPatternIdentifiers>;
    using StylesPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::StylesPatternIdentifiers>;
    using TableItemPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::TableItemPatternIdentifiers>;
    using TablePatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::TablePatternIdentifiers>;
    using TogglePatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::TogglePatternIdentifiers>;
    using TransformPattern2Identifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::TransformPattern2Identifiers>;
    using TransformPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::TransformPatternIdentifiers>;
    using ValuePatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::ValuePatternIdentifiers>;
    using WindowPatternIdentifiers = py::winrt_wrapper<winrt::Windows::UI::Xaml::Automation::WindowPatternIdentifiers>;
}

namespace py
{
}
