// WARNING: Please don't edit this file. It was generated by Python/WinRT v0.0.0

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "0.0.0"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Management.Deployment.h>

#include <winrt/Windows.Phone.Management.Deployment.h>

namespace py::proj::Windows::Phone::Management::Deployment
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Phone::Management::Deployment::EnterpriseStatus> = "i";


    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.EnterpriseEnrollmentStatus";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "EnterpriseEnrollmentStatus";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::EnterpriseStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.EnterpriseStatus";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "EnterpriseStatus";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::Enterprise>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.Enterprise";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "Enterprise";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.EnterpriseEnrollmentManager";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "EnterpriseEnrollmentManager";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.EnterpriseEnrollmentResult";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "EnterpriseEnrollmentResult";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::InstallationManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.InstallationManager";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "InstallationManager";
    };

    template<>
    struct py_type<winrt::Windows::Phone::Management::Deployment::PackageInstallResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.phone.management.deployment.PackageInstallResult";
        static constexpr const char* module_name = "winrt.windows.phone.management.deployment";
        static constexpr const char* type_name = "PackageInstallResult";
    };
}

#if __has_include("py.Windows.ApplicationModel.h")
#include "py.Windows.ApplicationModel.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Management.Deployment.h")
#include "py.Windows.Management.Deployment.h"
#endif

namespace py::impl::Windows::Phone::Management::Deployment
{
}

namespace py::wrapper::Windows::Phone::Management::Deployment
{
    using Enterprise = py::winrt_wrapper<winrt::Windows::Phone::Management::Deployment::Enterprise>;
    using EnterpriseEnrollmentManager = py::winrt_wrapper<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentManager>;
    using EnterpriseEnrollmentResult = py::winrt_wrapper<winrt::Windows::Phone::Management::Deployment::EnterpriseEnrollmentResult>;
    using InstallationManager = py::winrt_wrapper<winrt::Windows::Phone::Management::Deployment::InstallationManager>;
    using PackageInstallResult = py::winrt_wrapper<winrt::Windows::Phone::Management::Deployment::PackageInstallResult>;
}

namespace py
{
}
