// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Storage.Streams.h>

#include <winrt/Windows.ApplicationModel.Store.LicenseManagement.h>

namespace py::proj::Windows::ApplicationModel::Store::LicenseManagement
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseRefreshOption> = "i";


    template<>
    struct py_type<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseRefreshOption>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.store.licensemanagement.LicenseRefreshOption";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.store.licensemanagement";
        static constexpr const char* type_name = "LicenseRefreshOption";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseManager>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.store.licensemanagement.LicenseManager";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.store.licensemanagement";
        static constexpr const char* type_name = "LicenseManager";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseSatisfactionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.store.licensemanagement.LicenseSatisfactionInfo";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.store.licensemanagement";
        static constexpr const char* type_name = "LicenseSatisfactionInfo";
    };

    template<>
    struct py_type<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseSatisfactionResult>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.applicationmodel.store.licensemanagement.LicenseSatisfactionResult";
        static constexpr const char* module_name = "winrt.windows.applicationmodel.store.licensemanagement";
        static constexpr const char* type_name = "LicenseSatisfactionResult";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

namespace py::impl::Windows::ApplicationModel::Store::LicenseManagement
{
}

namespace py::wrapper::Windows::ApplicationModel::Store::LicenseManagement
{
    using LicenseManager = py::winrt_wrapper<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseManager>;
    using LicenseSatisfactionInfo = py::winrt_wrapper<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseSatisfactionInfo>;
    using LicenseSatisfactionResult = py::winrt_wrapper<winrt::Windows::ApplicationModel::Store::LicenseManagement::LicenseSatisfactionResult>;
}

namespace py
{
}
