// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");

#include <winrt/Windows.System.Display.h>

namespace py::proj::Windows::System::Display
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::System::Display::DisplayRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.display.DisplayRequest";
        static constexpr const char* module_name = "winrt.windows.system.display";
        static constexpr const char* type_name = "DisplayRequest";
    };
}

namespace py::impl::Windows::System::Display
{
}

namespace py::wrapper::Windows::System::Display
{
    using DisplayRequest = py::winrt_wrapper<winrt::Windows::System::Display::DisplayRequest>;
}

namespace py
{
}
