// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.System.h>

#include <winrt/Windows.Globalization.h>

namespace py::proj::Windows::Globalization
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Globalization::DayOfWeek> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::Globalization::LanguageLayoutDirection> = "i";


    template<>
    struct py_type<winrt::Windows::Globalization::DayOfWeek>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.DayOfWeek";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "DayOfWeek";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::LanguageLayoutDirection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.LanguageLayoutDirection";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "LanguageLayoutDirection";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::ApplicationLanguages>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.ApplicationLanguages";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "ApplicationLanguages";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::Calendar>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.Calendar";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "Calendar";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::CalendarIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.CalendarIdentifiers";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "CalendarIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::ClockIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.ClockIdentifiers";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "ClockIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::CurrencyAmount>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.CurrencyAmount";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "CurrencyAmount";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::CurrencyIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.CurrencyIdentifiers";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "CurrencyIdentifiers";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::GeographicRegion>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.GeographicRegion";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "GeographicRegion";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::JapanesePhoneme>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.JapanesePhoneme";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "JapanesePhoneme";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::JapanesePhoneticAnalyzer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.JapanesePhoneticAnalyzer";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "JapanesePhoneticAnalyzer";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::Language>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.Language";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "Language";
    };

    template<>
    struct py_type<winrt::Windows::Globalization::NumeralSystemIdentifiers>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.globalization.NumeralSystemIdentifiers";
        static constexpr const char* module_name = "winrt.windows.globalization";
        static constexpr const char* type_name = "NumeralSystemIdentifiers";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.System.h")
#include "py.Windows.System.h"
#endif

namespace py::impl::Windows::Globalization
{
}

namespace py::wrapper::Windows::Globalization
{
    using ApplicationLanguages = py::winrt_wrapper<winrt::Windows::Globalization::ApplicationLanguages>;
    using Calendar = py::winrt_wrapper<winrt::Windows::Globalization::Calendar>;
    using CalendarIdentifiers = py::winrt_wrapper<winrt::Windows::Globalization::CalendarIdentifiers>;
    using ClockIdentifiers = py::winrt_wrapper<winrt::Windows::Globalization::ClockIdentifiers>;
    using CurrencyAmount = py::winrt_wrapper<winrt::Windows::Globalization::CurrencyAmount>;
    using CurrencyIdentifiers = py::winrt_wrapper<winrt::Windows::Globalization::CurrencyIdentifiers>;
    using GeographicRegion = py::winrt_wrapper<winrt::Windows::Globalization::GeographicRegion>;
    using JapanesePhoneme = py::winrt_wrapper<winrt::Windows::Globalization::JapanesePhoneme>;
    using JapanesePhoneticAnalyzer = py::winrt_wrapper<winrt::Windows::Globalization::JapanesePhoneticAnalyzer>;
    using Language = py::winrt_wrapper<winrt::Windows::Globalization::Language>;
    using NumeralSystemIdentifiers = py::winrt_wrapper<winrt::Windows::Globalization::NumeralSystemIdentifiers>;
}

namespace py
{
}
