// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.ApplicationModel.AppService.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Networking.Sockets.h>
#include <winrt/Windows.Web.Http.h>

#include <winrt/Windows.System.Diagnostics.DevicePortal.h>

namespace py::proj::Windows::System::Diagnostics::DevicePortal
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionClosedReason> = "i";


    template<>
    struct py_type<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionClosedReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.deviceportal.DevicePortalConnectionClosedReason";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.deviceportal";
        static constexpr const char* type_name = "DevicePortalConnectionClosedReason";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.deviceportal.DevicePortalConnection";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.deviceportal";
        static constexpr const char* type_name = "DevicePortalConnection";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionClosedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.deviceportal.DevicePortalConnectionClosedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.deviceportal";
        static constexpr const char* type_name = "DevicePortalConnectionClosedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionRequestReceivedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.system.diagnostics.deviceportal.DevicePortalConnectionRequestReceivedEventArgs";
        static constexpr const char* module_name = "winrt.windows.system.diagnostics.deviceportal";
        static constexpr const char* type_name = "DevicePortalConnectionRequestReceivedEventArgs";
    };
}

#if __has_include("py.Windows.ApplicationModel.AppService.h")
#include "py.Windows.ApplicationModel.AppService.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Networking.Sockets.h")
#include "py.Windows.Networking.Sockets.h"
#endif

#if __has_include("py.Windows.Web.Http.h")
#include "py.Windows.Web.Http.h"
#endif

namespace py::impl::Windows::System::Diagnostics::DevicePortal
{
}

namespace py::wrapper::Windows::System::Diagnostics::DevicePortal
{
    using DevicePortalConnection = py::winrt_wrapper<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnection>;
    using DevicePortalConnectionClosedEventArgs = py::winrt_wrapper<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionClosedEventArgs>;
    using DevicePortalConnectionRequestReceivedEventArgs = py::winrt_wrapper<winrt::Windows::System::Diagnostics::DevicePortal::DevicePortalConnectionRequestReceivedEventArgs>;
}

namespace py
{
}
