// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.System.Power.h>

#include <winrt/Windows.Devices.Power.h>

namespace py::proj::Windows::Devices::Power
{
}

namespace py
{

    template<>
    struct py_type<winrt::Windows::Devices::Power::Battery>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.devices.power.Battery";
        static constexpr const char* module_name = "winrt.windows.devices.power";
        static constexpr const char* type_name = "Battery";
    };

    template<>
    struct py_type<winrt::Windows::Devices::Power::BatteryReport>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.devices.power.BatteryReport";
        static constexpr const char* module_name = "winrt.windows.devices.power";
        static constexpr const char* type_name = "BatteryReport";
    };

    template<>
    struct py_type<winrt::Windows::Devices::Power::PowerGridData>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.devices.power.PowerGridData";
        static constexpr const char* module_name = "winrt.windows.devices.power";
        static constexpr const char* type_name = "PowerGridData";
    };

    template<>
    struct py_type<winrt::Windows::Devices::Power::PowerGridForecast>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.devices.power.PowerGridForecast";
        static constexpr const char* module_name = "winrt.windows.devices.power";
        static constexpr const char* type_name = "PowerGridForecast";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.System.Power.h")
#include "py.Windows.System.Power.h"
#endif

namespace py::impl::Windows::Devices::Power
{
}

namespace py::wrapper::Windows::Devices::Power
{
    using Battery = py::winrt_wrapper<winrt::Windows::Devices::Power::Battery>;
    using BatteryReport = py::winrt_wrapper<winrt::Windows::Devices::Power::BatteryReport>;
    using PowerGridData = py::winrt_wrapper<winrt::Windows::Devices::Power::PowerGridData>;
    using PowerGridForecast = py::winrt_wrapper<winrt::Windows::Devices::Power::PowerGridForecast>;
}

namespace py
{
}
