// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Devices.Geolocation.h>
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.Foundation.Numerics.h>
#include <winrt/Windows.Services.Maps.h>
#include <winrt/Windows.Services.Maps.LocalSearch.h>
#include <winrt/Windows.Storage.Streams.h>
#include <winrt/Windows.UI.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Controls.h>

#include <winrt/Windows.UI.Xaml.Controls.Maps.h>

namespace py::proj::Windows::UI::Xaml::Controls::Maps
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapAnimationKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapCameraChangeReason> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapColorScheme> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapElementCollisionBehavior> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapInteractionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapLoadingStatus> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapModel3DShadingOption> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapPanInteractionMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapProjection> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapStyle> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapTileAnimationState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapTileLayer> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapVisibleRegionKind> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapWatermarkMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Controls::Maps::MapZoomLevelRange> = "T{d:min:d:max:}";


    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapAnimationKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapAnimationKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapAnimationKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapCameraChangeReason>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapCameraChangeReason";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapCameraChangeReason";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapColorScheme>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapColorScheme";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapColorScheme";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementCollisionBehavior>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementCollisionBehavior";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementCollisionBehavior";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapInteractionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapInteractionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapInteractionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapLoadingStatus>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapLoadingStatus";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapLoadingStatus";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapModel3DShadingOption>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapModel3DShadingOption";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapModel3DShadingOption";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapPanInteractionMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapPanInteractionMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapPanInteractionMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapProjection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapProjection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapProjection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapStyle>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapStyle";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapStyle";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileAnimationState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileAnimationState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileAnimationState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileLayer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileLayer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileLayer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapVisibleRegionKind>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapVisibleRegionKind";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapVisibleRegionKind";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapWatermarkMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapWatermarkMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapWatermarkMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::CustomMapTileDataSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.CustomMapTileDataSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "CustomMapTileDataSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::HttpMapTileDataSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.HttpMapTileDataSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "HttpMapTileDataSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::LocalMapTileDataSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.LocalMapTileDataSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "LocalMapTileDataSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapActualCameraChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapActualCameraChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapActualCameraChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapActualCameraChangingEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapActualCameraChangingEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapActualCameraChangingEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapBillboard>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapBillboard";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapBillboard";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapCamera>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapCamera";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapCamera";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapContextRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapContextRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapContextRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlBusinessLandmarkClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlBusinessLandmarkClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkPointerEnteredEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlBusinessLandmarkPointerEnteredEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlBusinessLandmarkPointerEnteredEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkPointerExitedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlBusinessLandmarkPointerExitedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlBusinessLandmarkPointerExitedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkRightTappedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlBusinessLandmarkRightTappedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlBusinessLandmarkRightTappedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlDataHelper>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlDataHelper";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlDataHelper";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeatureClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlTransitFeatureClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlTransitFeatureClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeaturePointerEnteredEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlTransitFeaturePointerEnteredEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlTransitFeaturePointerEnteredEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeaturePointerExitedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlTransitFeaturePointerExitedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlTransitFeaturePointerExitedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeatureRightTappedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapControlTransitFeatureRightTappedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapControlTransitFeatureRightTappedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapCustomExperience>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapCustomExperience";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapCustomExperience";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapCustomExperienceChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapCustomExperienceChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapCustomExperienceChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElement>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElement";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElement";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElement3D>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElement3D";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElement3D";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementPointerEnteredEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementPointerEnteredEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementPointerEnteredEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementPointerExitedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementPointerExitedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementPointerExitedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementsLayer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementsLayer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerClickEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementsLayerClickEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementsLayerClickEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerContextRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementsLayerContextRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementsLayerContextRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerPointerEnteredEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementsLayerPointerEnteredEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementsLayerPointerEnteredEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerPointerExitedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapElementsLayerPointerExitedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapElementsLayerPointerExitedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapIcon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapIcon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapIcon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapInputEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapInputEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapInputEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapItemsControl>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapItemsControl";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapItemsControl";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapLayer>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapLayer";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapLayer";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapModel3D>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapModel3D";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapModel3D";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapPolygon>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapPolygon";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapPolygon";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapPolyline>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapPolyline";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapPolyline";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapRightTappedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapRightTappedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapRightTappedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapRouteView>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapRouteView";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapRouteView";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapScene>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapScene";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapScene";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheet>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapStyleSheet";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapStyleSheet";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheetEntries>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapStyleSheetEntries";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapStyleSheetEntries";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheetEntryStates>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapStyleSheetEntryStates";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapStyleSheetEntryStates";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTargetCameraChangedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTargetCameraChangedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTargetCameraChangedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileBitmapRequest";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileBitmapRequest";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequestDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileBitmapRequestDeferral";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileBitmapRequestDeferral";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileBitmapRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileBitmapRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileDataSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileDataSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileDataSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileSource>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileSource";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileSource";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequest>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileUriRequest";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileUriRequest";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequestDeferral>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileUriRequestDeferral";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileUriRequestDeferral";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequestedEventArgs>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapTileUriRequestedEventArgs";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapTileUriRequestedEventArgs";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::StreetsideExperience>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.StreetsideExperience";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "StreetsideExperience";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::StreetsidePanorama>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.StreetsidePanorama";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "StreetsidePanorama";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Controls::Maps::MapZoomLevelRange>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_ui_xaml_controls_maps.MapZoomLevelRange_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.controls.maps.MapZoomLevelRange";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.controls.maps";
        static constexpr const char* type_name = "MapZoomLevelRange";
    };
}

#if __has_include("py.Windows.Devices.Geolocation.h")
#include "py.Windows.Devices.Geolocation.h"
#endif

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.Foundation.Numerics.h")
#include "py.Windows.Foundation.Numerics.h"
#endif

#if __has_include("py.Windows.Services.Maps.h")
#include "py.Windows.Services.Maps.h"
#endif

#if __has_include("py.Windows.Services.Maps.LocalSearch.h")
#include "py.Windows.Services.Maps.LocalSearch.h"
#endif

#if __has_include("py.Windows.Storage.Streams.h")
#include "py.Windows.Storage.Streams.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.h")
#include "py.Windows.UI.Xaml.Controls.h"
#endif

namespace py::impl::Windows::UI::Xaml::Controls::Maps
{
}

namespace py::wrapper::Windows::UI::Xaml::Controls::Maps
{
    using CustomMapTileDataSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::CustomMapTileDataSource>;
    using HttpMapTileDataSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::HttpMapTileDataSource>;
    using LocalMapTileDataSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::LocalMapTileDataSource>;
    using MapActualCameraChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapActualCameraChangedEventArgs>;
    using MapActualCameraChangingEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapActualCameraChangingEventArgs>;
    using MapBillboard = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapBillboard>;
    using MapCamera = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapCamera>;
    using MapContextRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapContextRequestedEventArgs>;
    using MapControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControl>;
    using MapControlBusinessLandmarkClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkClickEventArgs>;
    using MapControlBusinessLandmarkPointerEnteredEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkPointerEnteredEventArgs>;
    using MapControlBusinessLandmarkPointerExitedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkPointerExitedEventArgs>;
    using MapControlBusinessLandmarkRightTappedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlBusinessLandmarkRightTappedEventArgs>;
    using MapControlDataHelper = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlDataHelper>;
    using MapControlTransitFeatureClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeatureClickEventArgs>;
    using MapControlTransitFeaturePointerEnteredEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeaturePointerEnteredEventArgs>;
    using MapControlTransitFeaturePointerExitedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeaturePointerExitedEventArgs>;
    using MapControlTransitFeatureRightTappedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapControlTransitFeatureRightTappedEventArgs>;
    using MapCustomExperience = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapCustomExperience>;
    using MapCustomExperienceChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapCustomExperienceChangedEventArgs>;
    using MapElement = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElement>;
    using MapElement3D = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElement3D>;
    using MapElementClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementClickEventArgs>;
    using MapElementPointerEnteredEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementPointerEnteredEventArgs>;
    using MapElementPointerExitedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementPointerExitedEventArgs>;
    using MapElementsLayer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayer>;
    using MapElementsLayerClickEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerClickEventArgs>;
    using MapElementsLayerContextRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerContextRequestedEventArgs>;
    using MapElementsLayerPointerEnteredEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerPointerEnteredEventArgs>;
    using MapElementsLayerPointerExitedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapElementsLayerPointerExitedEventArgs>;
    using MapIcon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapIcon>;
    using MapInputEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapInputEventArgs>;
    using MapItemsControl = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapItemsControl>;
    using MapLayer = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapLayer>;
    using MapModel3D = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapModel3D>;
    using MapPolygon = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapPolygon>;
    using MapPolyline = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapPolyline>;
    using MapRightTappedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapRightTappedEventArgs>;
    using MapRouteView = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapRouteView>;
    using MapScene = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapScene>;
    using MapStyleSheet = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheet>;
    using MapStyleSheetEntries = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheetEntries>;
    using MapStyleSheetEntryStates = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapStyleSheetEntryStates>;
    using MapTargetCameraChangedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTargetCameraChangedEventArgs>;
    using MapTileBitmapRequest = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequest>;
    using MapTileBitmapRequestDeferral = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequestDeferral>;
    using MapTileBitmapRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileBitmapRequestedEventArgs>;
    using MapTileDataSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileDataSource>;
    using MapTileSource = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileSource>;
    using MapTileUriRequest = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequest>;
    using MapTileUriRequestDeferral = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequestDeferral>;
    using MapTileUriRequestedEventArgs = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapTileUriRequestedEventArgs>;
    using StreetsideExperience = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::StreetsideExperience>;
    using StreetsidePanorama = py::winrt_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::StreetsidePanorama>;
    using MapZoomLevelRange = py::winrt_struct_wrapper<winrt::Windows::UI::Xaml::Controls::Maps::MapZoomLevelRange>;
}

namespace py
{
}
