// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#pragma once

#include "pybase.h"
static_assert(winrt::check_version(PYWINRT_VERSION, "3.2.1"), "Mismatched Py/WinRT headers.");
#include <winrt/Windows.Foundation.h>
#include <winrt/Windows.Foundation.Collections.h>
#include <winrt/Windows.UI.h>
#include <winrt/Windows.UI.Composition.h>
#include <winrt/Windows.UI.Xaml.h>
#include <winrt/Windows.UI.Xaml.Controls.h>
#include <winrt/Windows.UI.Xaml.Controls.Primitives.h>

#include <winrt/Windows.UI.Xaml.Media.Animation.h>

namespace py::proj::Windows::UI::Xaml::Media::Animation
{
}

namespace py
{
    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::ClockState> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationComponent> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::EasingMode> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::FillBehavior> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehaviorType> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::SlideNavigationTransitionEffect> = "i";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::KeyTime> = "T{T{q:duration:}:time_span:}";

    template<>
    inline constexpr const char* buffer_format<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehavior> = "T{d:count:T{q:duration:}:duration:i:type:}";


    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ClockState>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ClockState";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ClockState";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationComponent>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ConnectedAnimationComponent";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ConnectedAnimationComponent";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EasingMode>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EasingMode";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EasingMode";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::FillBehavior>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.FillBehavior";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "FillBehavior";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehaviorType>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.RepeatBehaviorType";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "RepeatBehaviorType";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SlideNavigationTransitionEffect>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SlideNavigationTransitionEffect";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SlideNavigationTransitionEffect";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::AddDeleteThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.AddDeleteThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "AddDeleteThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::BackEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.BackEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "BackEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::BasicConnectedAnimationConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.BasicConnectedAnimationConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "BasicConnectedAnimationConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::BeginStoryboard>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.BeginStoryboard";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "BeginStoryboard";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::BounceEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.BounceEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "BounceEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::CircleEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.CircleEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "CircleEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ColorAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ColorAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ColorAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ColorAnimationUsingKeyFrames>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ColorAnimationUsingKeyFrames";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ColorAnimationUsingKeyFrames";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ColorKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ColorKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ColorKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ColorKeyFrameCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ColorKeyFrameCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ColorKeyFrameCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::CommonNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.CommonNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "CommonNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ConnectedAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ConnectedAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ConnectedAnimationConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ConnectedAnimationConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationService>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ConnectedAnimationService";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ConnectedAnimationService";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ContentThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ContentThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ContentThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ContinuumNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ContinuumNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ContinuumNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::CubicEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.CubicEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "CubicEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DirectConnectedAnimationConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DirectConnectedAnimationConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DirectConnectedAnimationConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DiscreteColorKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DiscreteColorKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DiscreteColorKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DiscreteDoubleKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DiscreteDoubleKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DiscreteDoubleKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DiscreteObjectKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DiscreteObjectKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DiscreteObjectKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DiscretePointKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DiscretePointKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DiscretePointKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DoubleAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DoubleAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DoubleAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DoubleAnimationUsingKeyFrames>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DoubleAnimationUsingKeyFrames";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DoubleAnimationUsingKeyFrames";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DoubleKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DoubleKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DoubleKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DoubleKeyFrameCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DoubleKeyFrameCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DoubleKeyFrameCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DragItemThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DragItemThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DragItemThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DragOverThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DragOverThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DragOverThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DrillInNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DrillInNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DrillInNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DrillInThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DrillInThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DrillInThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DrillOutThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DrillOutThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DrillOutThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::DropTargetItemThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.DropTargetItemThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "DropTargetItemThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EasingColorKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EasingColorKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EasingColorKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EasingDoubleKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EasingDoubleKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EasingDoubleKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EasingFunctionBase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EasingFunctionBase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EasingFunctionBase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EasingPointKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EasingPointKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EasingPointKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EdgeUIThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EdgeUIThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EdgeUIThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ElasticEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ElasticEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ElasticEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EntranceNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EntranceNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EntranceNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::EntranceThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.EntranceThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "EntranceThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ExponentialEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ExponentialEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ExponentialEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::FadeInThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.FadeInThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "FadeInThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::FadeOutThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.FadeOutThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "FadeOutThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::GravityConnectedAnimationConfiguration>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.GravityConnectedAnimationConfiguration";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "GravityConnectedAnimationConfiguration";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::KeySpline>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.KeySpline";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "KeySpline";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::KeyTimeHelper>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.KeyTimeHelper";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "KeyTimeHelper";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::LinearColorKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.LinearColorKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "LinearColorKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::LinearDoubleKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.LinearDoubleKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "LinearDoubleKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::LinearPointKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.LinearPointKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "LinearPointKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::NavigationThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.NavigationThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "NavigationThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::NavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.NavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "NavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ObjectAnimationUsingKeyFrames>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ObjectAnimationUsingKeyFrames";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ObjectAnimationUsingKeyFrames";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ObjectKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ObjectKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ObjectKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ObjectKeyFrameCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ObjectKeyFrameCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ObjectKeyFrameCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PaneThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PaneThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PaneThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointAnimationUsingKeyFrames>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointAnimationUsingKeyFrames";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointAnimationUsingKeyFrames";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointKeyFrameCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointKeyFrameCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointKeyFrameCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointerDownThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointerDownThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointerDownThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PointerUpThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PointerUpThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PointerUpThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PopInThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PopInThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PopInThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PopOutThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PopOutThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PopOutThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PopupThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PopupThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PopupThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::PowerEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.PowerEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "PowerEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::QuadraticEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.QuadraticEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "QuadraticEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::QuarticEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.QuarticEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "QuarticEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::QuinticEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.QuinticEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "QuinticEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::ReorderThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.ReorderThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "ReorderThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehaviorHelper>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.RepeatBehaviorHelper";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "RepeatBehaviorHelper";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::RepositionThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.RepositionThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "RepositionThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::RepositionThemeTransition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.RepositionThemeTransition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "RepositionThemeTransition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SineEase>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SineEase";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SineEase";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SlideNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SlideNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SlideNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SplineColorKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SplineColorKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SplineColorKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SplineDoubleKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SplineDoubleKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SplineDoubleKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SplinePointKeyFrame>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SplinePointKeyFrame";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SplinePointKeyFrame";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SplitCloseThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SplitCloseThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SplitCloseThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SplitOpenThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SplitOpenThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SplitOpenThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::Storyboard>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.Storyboard";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "Storyboard";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SuppressNavigationTransitionInfo>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SuppressNavigationTransitionInfo";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SuppressNavigationTransitionInfo";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SwipeBackThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SwipeBackThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SwipeBackThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::SwipeHintThemeAnimation>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.SwipeHintThemeAnimation";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "SwipeHintThemeAnimation";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::Timeline>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.Timeline";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "Timeline";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::TimelineCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.TimelineCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "TimelineCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::Transition>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.Transition";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "Transition";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::TransitionCollection>
    {
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.TransitionCollection";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "TransitionCollection";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::KeyTime>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_ui_xaml_media_animation.KeyTime_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.KeyTime";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "KeyTime";
    };

    template<>
    struct py_type<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehavior>
    {
        static constexpr std::string_view from_tuple = "winrt._winrt_windows_ui_xaml_media_animation.RepeatBehavior_from_tuple";
        static constexpr std::string_view qualified_name = "winrt.windows.ui.xaml.media.animation.RepeatBehavior";
        static constexpr const char* module_name = "winrt.windows.ui.xaml.media.animation";
        static constexpr const char* type_name = "RepeatBehavior";
    };
}

#if __has_include("py.Windows.Foundation.h")
#include "py.Windows.Foundation.h"
#endif

#if __has_include("py.Windows.Foundation.Collections.h")
#include "py.Windows.Foundation.Collections.h"
#endif

#if __has_include("py.Windows.UI.h")
#include "py.Windows.UI.h"
#endif

#if __has_include("py.Windows.UI.Composition.h")
#include "py.Windows.UI.Composition.h"
#endif

#if __has_include("py.Windows.UI.Xaml.h")
#include "py.Windows.UI.Xaml.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.h")
#include "py.Windows.UI.Xaml.Controls.h"
#endif

#if __has_include("py.Windows.UI.Xaml.Controls.Primitives.h")
#include "py.Windows.UI.Xaml.Controls.Primitives.h"
#endif

namespace py::impl::Windows::UI::Xaml::Media::Animation
{
}

namespace py::wrapper::Windows::UI::Xaml::Media::Animation
{
    using AddDeleteThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::AddDeleteThemeTransition>;
    using BackEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::BackEase>;
    using BasicConnectedAnimationConfiguration = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::BasicConnectedAnimationConfiguration>;
    using BeginStoryboard = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::BeginStoryboard>;
    using BounceEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::BounceEase>;
    using CircleEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::CircleEase>;
    using ColorAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ColorAnimation>;
    using ColorAnimationUsingKeyFrames = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ColorAnimationUsingKeyFrames>;
    using ColorKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ColorKeyFrame>;
    using ColorKeyFrameCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ColorKeyFrameCollection>;
    using CommonNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::CommonNavigationTransitionInfo>;
    using ConnectedAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimation>;
    using ConnectedAnimationConfiguration = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationConfiguration>;
    using ConnectedAnimationService = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ConnectedAnimationService>;
    using ContentThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ContentThemeTransition>;
    using ContinuumNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ContinuumNavigationTransitionInfo>;
    using CubicEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::CubicEase>;
    using DirectConnectedAnimationConfiguration = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DirectConnectedAnimationConfiguration>;
    using DiscreteColorKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DiscreteColorKeyFrame>;
    using DiscreteDoubleKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DiscreteDoubleKeyFrame>;
    using DiscreteObjectKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DiscreteObjectKeyFrame>;
    using DiscretePointKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DiscretePointKeyFrame>;
    using DoubleAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DoubleAnimation>;
    using DoubleAnimationUsingKeyFrames = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DoubleAnimationUsingKeyFrames>;
    using DoubleKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DoubleKeyFrame>;
    using DoubleKeyFrameCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DoubleKeyFrameCollection>;
    using DragItemThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DragItemThemeAnimation>;
    using DragOverThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DragOverThemeAnimation>;
    using DrillInNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DrillInNavigationTransitionInfo>;
    using DrillInThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DrillInThemeAnimation>;
    using DrillOutThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DrillOutThemeAnimation>;
    using DropTargetItemThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::DropTargetItemThemeAnimation>;
    using EasingColorKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EasingColorKeyFrame>;
    using EasingDoubleKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EasingDoubleKeyFrame>;
    using EasingFunctionBase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EasingFunctionBase>;
    using EasingPointKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EasingPointKeyFrame>;
    using EdgeUIThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EdgeUIThemeTransition>;
    using ElasticEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ElasticEase>;
    using EntranceNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EntranceNavigationTransitionInfo>;
    using EntranceThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::EntranceThemeTransition>;
    using ExponentialEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ExponentialEase>;
    using FadeInThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::FadeInThemeAnimation>;
    using FadeOutThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::FadeOutThemeAnimation>;
    using GravityConnectedAnimationConfiguration = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::GravityConnectedAnimationConfiguration>;
    using KeySpline = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::KeySpline>;
    using KeyTimeHelper = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::KeyTimeHelper>;
    using LinearColorKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::LinearColorKeyFrame>;
    using LinearDoubleKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::LinearDoubleKeyFrame>;
    using LinearPointKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::LinearPointKeyFrame>;
    using NavigationThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::NavigationThemeTransition>;
    using NavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::NavigationTransitionInfo>;
    using ObjectAnimationUsingKeyFrames = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ObjectAnimationUsingKeyFrames>;
    using ObjectKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ObjectKeyFrame>;
    using ObjectKeyFrameCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ObjectKeyFrameCollection>;
    using PaneThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PaneThemeTransition>;
    using PointAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointAnimation>;
    using PointAnimationUsingKeyFrames = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointAnimationUsingKeyFrames>;
    using PointKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointKeyFrame>;
    using PointKeyFrameCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointKeyFrameCollection>;
    using PointerDownThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointerDownThemeAnimation>;
    using PointerUpThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PointerUpThemeAnimation>;
    using PopInThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PopInThemeAnimation>;
    using PopOutThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PopOutThemeAnimation>;
    using PopupThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PopupThemeTransition>;
    using PowerEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::PowerEase>;
    using QuadraticEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::QuadraticEase>;
    using QuarticEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::QuarticEase>;
    using QuinticEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::QuinticEase>;
    using ReorderThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::ReorderThemeTransition>;
    using RepeatBehaviorHelper = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehaviorHelper>;
    using RepositionThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::RepositionThemeAnimation>;
    using RepositionThemeTransition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::RepositionThemeTransition>;
    using SineEase = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SineEase>;
    using SlideNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SlideNavigationTransitionInfo>;
    using SplineColorKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SplineColorKeyFrame>;
    using SplineDoubleKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SplineDoubleKeyFrame>;
    using SplinePointKeyFrame = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SplinePointKeyFrame>;
    using SplitCloseThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SplitCloseThemeAnimation>;
    using SplitOpenThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SplitOpenThemeAnimation>;
    using Storyboard = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::Storyboard>;
    using SuppressNavigationTransitionInfo = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SuppressNavigationTransitionInfo>;
    using SwipeBackThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SwipeBackThemeAnimation>;
    using SwipeHintThemeAnimation = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::SwipeHintThemeAnimation>;
    using Timeline = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::Timeline>;
    using TimelineCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::TimelineCollection>;
    using Transition = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::Transition>;
    using TransitionCollection = py::winrt_wrapper<winrt::Windows::UI::Xaml::Media::Animation::TransitionCollection>;
    using KeyTime = py::winrt_struct_wrapper<winrt::Windows::UI::Xaml::Media::Animation::KeyTime>;
    using RepeatBehavior = py::winrt_struct_wrapper<winrt::Windows::UI::Xaml::Media::Animation::RepeatBehavior>;
}

namespace py
{
}
